unit VaxServerCOM;

interface

uses
    Classes,
    ComObj,
    Vcl.OleCtrls,
    Vcl.ComCtrls,
    Vcl.Forms,
    Vcl.OleServer,
    VaxTeleServerCOMLib_TLB;

type TVaxServerCOM = class(TVaxServerSIP)

        public
        const VAX_PEER_TYPE_USER = 3001;
        const VAX_PEER_TYPE_LINE = 3002;
        const VAX_PEER_TYPE_DIRECT_PROXY = 3003;

        const VAX_CONF_ROOM_NORMAL_LISTENER = 100;
        const VAX_CONF_ROOM_STEALTH_LISTENER = 101;
        const VAX_CONF_ROOM_STEALTH_SPEAKER = 102;

        const VAX_DIGIT_DTMF_TYPE_RTP	= 0;
        const VAX_DIGIT_DTMF_TYPE_INBAND = 1;
        const VAX_DIGIT_DTMF_TYPE_SIP	= 2;

        const VAX_CALL_CHANNEL_ZERO = 0;
        const VAX_CALL_CHANNEL_ONE = 1;

        private
        m_pVaxServerLibCOM: TVaxServerSIP;

        {///////////////////////////////////////////////////////////////////////////////
        ///////////////////     Functions
        ///////////////////////////////////////////////////////////////////////////////}

        public

        constructor Create();

        procedure InvokeEvent(DispID: LongInt; var Params: TVariantArray); override;

        procedure SetLicenseKey(sLicenseKey: String);

        function Initialize(sDomainRealm: String; sSIPListenIP: String; nSIPListenPort: Integer; sRTPListenIP: String; nRTPListenPort: Integer): Boolean;
        procedure UnInitialize();

        function AddUser(sUserName: String; sPassword: String; sCodecList: String): Boolean;
        procedure RemoveUser(sUserName: String);

        function AcceptRegister(nRegId: Integer): Boolean;
        function RejectRegister(nRegId: Integer; nStatusCode: Integer; sReasonPhrase: String): Boolean;
        function AuthRegister(nRegId: Integer): Boolean;

        function AddLine(sLineName: String; sDisplayName: String; sUserName: String; sAuthUser: String; sAuthPwd: String; sDomainRealm: String; sProxySIP: String; sOutboundProxySIP: String; sCodecList: String): Boolean;
        procedure RemoveLine(sLineName: String);

        function RegisterLine(sLineName: String): Boolean;
        function UnRegisterLine(sLineName: String): Boolean;

        function AddDirectProxySIP(sProxyName: String; sAuthLogin: String; sAuthPwd: String; sDomainRealm: String; sProxyIP: String; nProxyPort: Integer; sCodecList: String): Boolean;
        procedure RemoveDirectProxySIP(sProxyName: String);

        function AcceptCallSession(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nToPeerType: Integer; sToPeerName: String; nTimeout: Integer): Boolean;
        procedure RejectCallSession(nSessionId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        procedure CloseCallSession(nSessionId: Integer);

        function DialCallSession(sCallerName: String; sCallerId: String; sDialNo: String; nToPeerType: Integer; sToPeerName: String; nTimeout: Integer): Integer;

        function AcceptTransferBlind(nTransfererSessionId: Integer; sCallerName: String; sCallerId: String; sTransferTo: String; nToPeerType: Integer; sToPeerName: String; nTimeout: Integer): Boolean;
        function AcceptTransferConsult(nTransfererSessionId: Integer; nTransferToSessionId: Integer): Boolean;
        procedure RejectTransfer(nSessionId: Integer);

        function PlayWaveStartToCallSession(nSessionId: Integer; nChannelId: Integer; nWaveId: Integer; bLoopPlay: Boolean; nPlayPos: Integer): Boolean;
        procedure PlayWaveStopToCallSession(nSessionId: Integer; nChannelId: Integer; nWaveId: Integer);

        function RecordWaveStartToCallSession(nSessionId: Integer; nChannelId: Integer; sFileName: String): Boolean;
        procedure RecordWaveStopToCallSession(nSessionId: Integer; nChannelId: Integer);
        function RecordWavePauseToCallSession(nSessionId: Integer; nChannelId: Integer; bEnable: Boolean): Boolean;

        function LoadWaveFile(sFileName: String): Integer;
        procedure UnLoadWaveFile(lWaveId: Integer);

        function LoadMusicHold(sFileName: String): Boolean;
        procedure UnLoadMusicHold();

        function AcceptOnHoldRequest(nSessionId : Integer): Boolean;
        function AcceptOffHoldRequest(nSessionId: Integer): Boolean;

        function AcceptChatMessage(nChatMsgId: Integer; nToPeerType: Integer; sToPeerName: String): Boolean;
        procedure RejectChatMessage(nChatMsgId: Integer; nStatusCode: Integer; sReasonPhrase: String);

        function AcceptChatStatusSubscribe(nStatusSubscribe: Integer; sMsgFrom: String; sMsgTo: String; nToPeerType: Integer; sToPeerName: String): Boolean;
        procedure RejectChatStatusSubscribe(nStatusSubscribe: Integer; sMsgFrom: String; sMsgTo: String);

        function OpenConferenceRoom(sRoomName: String): Boolean;
        procedure CloseConferenceRoom(sRoomName: String);

        function AddCallSessionToConferenceRoom(sRoomName: String; nSessionId: Integer; nType: Integer): Boolean;
        function RemoveCallSessionFromConferenceRoom(nSessionId: Integer): Boolean;

        function PlayWaveStartToConferenceRoom(sRoomName: String; lWaveId: Integer; bLoop: Boolean; nPlayPos: Integer): Boolean;
        function PlayWaveStopToConferenceRoom(sRoomName: String; lWaveId: Integer): Boolean;

        function RecordWaveStartToConferenceRoom(sRoomName: String; sFileName: String): Boolean;
        function RecordWaveStopToConferenceRoom(sRoomName: String): Boolean;
        function RecordWavePauseToConferenceRoom(sRoomName: String; bEnable: Boolean): Boolean;

        function VoiceSessionLost(bEnable: Boolean; nTimeout: Integer): Boolean;

        function SendInfoVM(sUserLogin: String; nNewMsgCount: Integer; nOldMsgCount: Integer; bMsgWaiting: Boolean): Integer;

        function StartVaxTeleTick(nTickId: Integer; nElapse: Integer): Boolean;
        function StopVaxTeleTick(nTickId: Integer): Boolean;

        function SetUserAgentName(sName: String): Boolean;
        function GetUserAgentName(): String;

        function SetSessionNameSDP(sName: String): Boolean;
        function GetSessionNameSDP(): String;

        function SendDTMFCallSession(nSessionId: Integer; nChannelId: Integer; nTypeDTMF: Integer; nDigit: Integer): Boolean;
        function DetectDigitDTMF(nSessionId: Integer; nChannelId: Integer; nTypeDTMF: Integer; bEnable: Boolean; nTimeout: Integer): Boolean;

        function GetVaxErrorCode(): Integer;

        function DialToneToCallSession(bEnable: Boolean; nSessionId: Integer; nWaveId: Integer): Boolean;
        function DiagnosticLogSIP(bInbound: Boolean; bOutbound: Boolean): Boolean;

        function AddRingGroup(sGroupName: String): Boolean;
        procedure RemoveRingGroup(sGroupName: String);
        function AddRingGroupAgent(sGroupName: String; sUserName: String): Boolean;
        procedure RemoveRingGroupAgent(sGroupName: String; sUserName: String);
        function SetRingGroupProcessMode(sGroupName: String; nModeId: Integer; nModeType: Integer): Boolean;
        function SetRingGroupAgentPriority(sGroupName: String; sUserName: String; nPriority: Integer): Boolean;

        function AddCallSessionToRingGroup(sGroupName: String; sCallerName: String; sCallerId: String; nSessionId: Integer): WordBool;
        function AddCallPickUpGroup(sGroupName: String): Boolean;
        procedure RemoveCallPickUpGroup(sGroupName: String);
        function AddCallPickUpGroupMember(sGroupName: String; sUserName: String): Boolean;
        procedure RemoveCallPickUpGroupMember(sGroupName: String; sUserName: String);

        function PickUpCall(nSessionId: Integer; sUserName: String): Boolean;
        function ParkCallSession(nSessionId: Integer; nChannelId: Integer; nSlotId: Integer): Boolean;
        function ConnectToParkedCallSession(nSessionId: Integer; nChannelId: Integer; nSlotId: Integer): Boolean;

        function AddQueue(sQueueName: String): Boolean;
        procedure RemoveQueue(sQueueName: String);
        function AddQueueAgent(sQueueName: String; sUserName: String): Boolean;
        procedure RemoveQueueAgent(sQueueName: String; sUserName: String);
        function SetQueueAgentPriority(sQueueName: String; sUserName: String; nPriority: Integer): Boolean;
        function SetQueueAgentStatus(sQueueName: String; sAgentName: String; lStatusId: Integer): Boolean;
        function SetQueueProcessMode(sQueueName: String; nModeId: Integer; nProcessModeType: Integer): Boolean;
        function AddCallSessionToQueue(sQueueName: String; sCallerName: String; sCallerId: String; nSessionId: Integer; nTimeout: Integer): Boolean;
        function AddStealthListener(nStealthSessionId: Integer; nCapturePeerType: Integer; sCapturePeerName: String; nListenType: Integer): Boolean;
        function MoveCall(nSrcSessionId: Integer; nChannelId: Integer; nDscSessionId: Integer): Boolean;

        function ConnectToServerREC(nSessionId: Integer; nChannelId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nToPeerType: Integer; sToPeerName: String; nTimeout: Integer): Boolean;
        function SetExtDataREC(nSessionId: Integer; nChannelId: Integer; sExtData: String): Boolean;
        function SendNotifyMsgSIP(sMsgFrom: String; sMsgTo: String; sToPeerType: Integer; sToPeerName: String): Integer;

        {///////////////////////////////////////////////////////////////////////////////
        ///////////////////     Events
        ///////////////////////////////////////////////////////////////////////////////}

        public

        procedure OnLineRegisterTrying(sLineName: String); virtual;
        procedure OnLineRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnLineRegisterSuccess(sLineName: String); virtual;

        procedure OnLineUnRegisterTrying(sLineName: String); virtual;
        procedure OnLineUnRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnLineUnRegisterSuccess(sLineName: String); virtual;

        procedure OnUnRegisterUser(sUserLogin: String); virtual;
        procedure OnRegisterUser(sUserLogin: String; sDomain: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); virtual;
        procedure OnRegisterUserSuccess(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); virtual;
        procedure OnRegisterUserFailed(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); virtual;

        procedure OnChatMessageText(nChatMsgId: Integer; sMsgFrom: String; sMsgTo: String; sMsgText: String; nFromPeerType: Integer; sFromPeerName: String; sFromIP: String; nFromPort: Integer); virtual;
        procedure OnChatMessageTyping(nChatMsgId: Integer; sMsgFrom: String; sMsgTo: String; bIsTypingStart: Boolean; nFromPeerType: Integer; sFromPeerName: String; sFromIP: String; nFromPort: Integer); virtual;
        procedure OnChatStatusSubscribe(nSubscrbId: Integer; sMsgFrom: String; sMsgTo: String; nFromPeerType: Integer; sFromPeerName: String; sFromIP: String; nFromPort: Integer); virtual;

        procedure OnChatMessageSuccess(nChatMsgId: Integer); virtual;
        procedure OnChatMessageFailed(nChatMsgId: Integer; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnChatMessageTimeout(nChatMsgId: Integer); virtual;

        procedure OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer); virtual;
        procedure OnCallSessionFailed(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnCallSessionConnected(nSessionId: Integer); virtual;
        procedure OnCallSessionClosed(nSessionId: Integer; nChannelId: Integer; nReasonCode: Integer); virtual;

        procedure OnCallSessionConnecting(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnCallSessionLost(nSessionId: Integer; nChannelId: Integer); virtual;
        procedure OnCallSessionHangup(nSessionId: Integer; nChannelId: Integer); virtual;
        procedure OnCallSessionTimeout(nSessionId: Integer; nChannelId: Integer); virtual;
        procedure OnCallSessionCancelled(nSessionId: Integer); virtual;

        procedure OnCallSessionOnHold(nSessionId: Integer; nChannelId: Integer); virtual;
        procedure OnCallSessionOffHold(nSessionId: Integer; nChannelId: Integer); virtual;

        procedure OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String); virtual;
        procedure OnCallSessionTransferConsult(nTransfererSessionId: Integer; nTransfererChannelId: Integer; nTransferToSessionId: Integer; nTransferToChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String); virtual;

        procedure OnCallSessionTransfering(nSessionId: Integer; nTransferType: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnCallSessionTransferFailed(nSessionId: Integer; nTransferType: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnCallSessionTransferTimeout(nSessionId: Integer; nTransferType: Integer; nChannelId: Integer); virtual;
        procedure OnCallSessionTransfered(nSessionId: Integer; nTransferType: Integer); virtual;

        procedure OnDetectedDigitDTMF(nSessionId: Integer; nChannelId: Integer; sDigitDTMF: String); virtual;
        procedure OnOutgoingDiagnosticLog(sMsgSIP: String; sToIP: String; nToPort: Integer); virtual;
        procedure OnIncomingDiagnosticLog(sMsgSIP: String; sFromIP: String; nFromPort: Integer); virtual;

        procedure OnVaxTeleTick(nTickId: Integer); virtual;

        procedure OnSendTimeoutVM(nMsgIdVM: Integer); virtual;
        procedure OnSendSuccessVM(nMsgIdVM: Integer); virtual;

        procedure OnCallSessionDialToneStart(nSessionId: Integer; nChannelId: Integer; nWaveId: Integer); virtual;
        procedure OnCallSessionDialToneStop(nSessionId: Integer; nChannelId: Integer; nWaveId: Integer); virtual;

        procedure OnBusyLampSubscribe(nSubscrbId: Integer; sUserName: String; sToUserName: String; sFromIP: String; nFromPort: Integer); virtual;
        procedure OnBusyLampUnSubscribe(nSubscrbId: Integer; sUserName: String; sToUserName: String; sFromIP: String; nFromPort: Integer); virtual;
        procedure OnBusyLampSubscribeSuccess(nSubscrbId: Integer; sUserName: String); virtual;
        procedure OnBusyLampSubscribeFailed(nSubscrbId: Integer; UserName: String); virtual;
        procedure OnBusyLampSendStatus(sFromUserName: String; sToUserName: String; nStateId: Integer); virtual;

        procedure OnCallSessionPlayWaveDone(nSessionId: Integer; nChannelId: Integer; nWaveId: Integer); virtual;
        procedure OnConferenceRoomPlayWaveDone(sRoomName: String; nWaveId: Integer); virtual;

        procedure OnCallSessionCreated(nSessionId: Integer; nChannelId: Integer); virtual;
        procedure OnCallSessionDetectedAMD(nSessionId: Integer; nChannelId: Integer; bIsHuman: Boolean); virtual;

        procedure OnCallSessionRecordedPCM(nSessionId: Integer; nChannelId: Integer; nDataPCM: Int64; nSizePCM: Integer; nTypePCM: Integer); virtual;
        procedure OnConferenceRoomRecordedPCM(sRoomName: String; nDataPCM: Int64; nSizePCM: Integer; nTypePCM: Integer); virtual;

        procedure OnVaxErrorLog(sFuncName: String; nErrorCode: Integer; sErrorMsg: String); virtual;

        procedure OnAddCallSessionToQueueSuccess(sQueueName: String; nSessionId: Integer); virtual;
        procedure OnAddCallSessionToQueueFailed(sQueueName: String; nSessionId: Integer); virtual;

        procedure OnVaxLicenseChannel(nTotalChannels: Integer; nUsedChannels: Integer); virtual;

        procedure OnAddCallSessionToRingGroupSuccess(sGroupName: String; nSessionId: Integer); virtual;
        procedure OnAddCallSessionToRingGroupFailed(sGroupName: String; nSessionId: Integer); virtual;

        procedure OnSendReqTransferCallTimeout(nSessionId: Integer; nChannelId: Integer); virtual;
        procedure OnSendReqTransferCallAccepted(nSessionId: Integer; nChannelId: Integer); virtual;
        procedure OnSendReqTransferCallFailed(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String); virtual;

        procedure OnQualityReportPUBLISH(sMsgSIP: String; sMsgSDP: String; sFromIP: String; nFromPort: Integer); virtual;

        procedure OnServerConnectingREC(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnServerConnectedREC(nSessionId: Integer; nChannelId: Integer); virtual;
        procedure OnServerFailedREC(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnServerTimeoutREC(nSessionId: Integer; nChannelId: Integer); virtual;
        procedure OnServerHungupREC(nSessionId: Integer; nChannelId: Integer); virtual;

        procedure OnQueuePlayWaveStart(nEventType: Integer; sQueueName: String; nSessionId: Integer); virtual;
        procedure OnQueuePlayWaveStop(nEventType: Integer; sQueueName: String; nSessionId: Integer); virtual;

        procedure OnQueueAgentConnectStarted(sQueueName: String; sAgentName: String; nSessionId: Integer); virtual;
        procedure OnQueueAgentConnectTrying(sQueueName: String; sAgentName: String; nSessionId: Integer; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnQueueAgentConnectFailed(sQueueName: String; sAgentName: String; nSessionId: Integer; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnQueueAgentConnectTimeout(sQueueName: String; sAgentName: String; nSessionId: Integer); virtual;
        procedure OnQueueAgentConnectSuccess(sQueueName: String; sAgentName: String; nSessionId: Integer); virtual;

        procedure OnChatStatusSendSubscribeSuccess(nSubscrbId: Integer); virtual;
        procedure OnChatStatusSendSubscribeFailed(nSubscrbId: Integer; nStatusCode: Integer; sReasonPhrase: String); virtual;

        procedure OnSendNotifyMsgSuccess(nMsgId: Integer); virtual;
        procedure OnSendNotifyMsgFailed(nMsgId: Integer; nStatusCode: Integer; sReasonPhrase: String); virtual;

end;


implementation

{$ASSERTIONS ON}

        {///////////////////////////////////////////////////////////////////////////////
        ///////////////////     Functions
        ///////////////////////////////////////////////////////////////////////////////}

        constructor TVaxServerCOM.Create();
        begin
            if m_pVaxServerLibCOM = nil then
                m_pVaxServerLibCOM := inherited Create(Nil);
        end;

        procedure TVaxServerCOM.InvokeEvent(DispID: LongInt; var Params: TVariantArray);

        begin
  case DispID of
    -1: Exit;  // DISPID_UNKNOWN
    1: OnRegisterUser(Params[0] {const WideString},
                      Params[1] {const WideString},
                      Params[2] {const WideString},
                      Params[3] {const WideString},
                      Params[4] {Integer},
                      Params[5] {Integer});

    2: OnRegisterUserSuccess(Params[0] {const WideString},
                             Params[1] {const WideString},
                             Params[2] {Integer},
                             Params[3] {Integer});

    3: OnRegisterUserFailed(Params[0] {const WideString},
                            Params[1] {const WideString},
                            Params[2] {Integer},
                            Params[3] {Integer});

    4: OnUnRegisterUser(Params[0] {const WideString});

    5: OnIncomingCall(Params[0] {Integer},
                      Params[1] {const WideString},
                      Params[2] {const WideString},
                      Params[3] {const WideString},
                      Params[4] {Integer},
                      Params[5] {const WideString},
                      Params[6] {const WideString},
                      Params[7] {const WideString},
                      Params[8] {Integer});

    6: OnCallSessionFailed(Params[0] {Integer},
                           Params[1] {Integer},
                           Params[2] {Integer},
                           Params[3] {const WideString});

    7: OnCallSessionConnected(Params[0] {Integer});

    8: OnCallSessionClosed(Params[0] {Integer},
                           Params[1] {Integer},
                           Params[2] {Integer});

    9: OnCallSessionOnHold(Params[0] {Integer},
                           Params[1] {Integer});

    10: OnCallSessionOffHold(Params[0] {Integer},
                             Params[1] {Integer});

    11: OnCallSessionTransferBlind(Params[0] {Integer},
                                   Params[1] {Integer},
                                   Params[2] {const WideString},
                                   Params[3] {const WideString},
                                   Params[4] {const WideString});

    12: OnCallSessionTransferConsult(Params[0] {Integer},
                                     Params[1] {Integer},
                                     Params[2] {Integer},
                                     Params[3] {Integer},
                                     Params[4] {const WideString},
                                     Params[5] {const WideString},
                                     Params[6] {const WideString});

    13: OnLineRegisterTrying(Params[0] {const WideString});

    14: OnLineRegisterFailed(Params[0] {const WideString},
                             Params[1] {Integer},
                             Params[2] {const WideString});

    15: OnLineRegisterSuccess(Params[0] {const WideString});

    16: OnLineUnRegisterTrying(Params[0] {const WideString});

    17: OnLineUnRegisterFailed(Params[0] {const WideString},
                               Params[1] {Integer},
                               Params[2] {const WideString});

    18: OnLineUnRegisterSuccess(Params[0] {const WideString});

    19: OnChatMessageText(Params[0] {Integer},
                          Params[1] {const WideString},
                          Params[2] {const WideString},
                          Params[3] {const WideString},
                          Params[4] {Integer},
                          Params[5] {const WideString},
                          Params[6] {const WideString},
                          Params[7] {Integer});

    20: OnChatMessageTyping(Params[0] {Integer},
                            Params[1] {const WideString},
                            Params[2] {const WideString},
                            Params[3] {WordBool},
                            Params[4] {Integer},
                            Params[5] {const WideString},
                            Params[6] {const WideString},
                            Params[7] {Integer});

    21: OnChatStatusSubscribe(Params[0] {Integer},
                              Params[1] {const WideString},
                              Params[2] {const WideString},
                              Params[3] {Integer},
                              Params[4] {const WideString},
                              Params[5] {const WideString},
                              Params[6] {Integer});

    22: OnChatMessageSuccess(Params[0] {Integer});

    23: OnChatMessageFailed(Params[0] {Integer},
                            Params[1] {Integer},
                            Params[2] {const WideString});

    24: OnChatMessageTimeout(Params[0] {Integer});

    25: OnOutgoingDiagnosticLog(Params[0] {const WideString},
                                Params[1] {const WideString},
                                Params[2] {Integer});

    26: OnIncomingDiagnosticLog(Params[0] {const WideString},
                                Params[1] {const WideString},
                                Params[2] {Integer});

    27: OnDetectedDigitDTMF(Params[0] {Integer},
                            Params[1] {Integer},
                            Params[2] {const WideString});

    28: OnVaxTeleTick(Params[0] {Integer});

    29: OnSendTimeoutVM(Params[0] {Integer});

    30: OnSendSuccessVM(Params[0] {Integer});

    31: OnCallSessionDialToneStart(Params[0] {Integer},
                                   Params[1] {Integer},
                                   Params[2] {Integer});

    32: OnCallSessionDialToneStop(Params[0] {Integer},
                                  Params[1] {Integer},
                                  Params[2] {Integer});

    33: OnCallSessionPlayWaveDone(Params[0] {Integer},
                                  Params[1] {Integer},
                                  Params[2] {Integer});

    34: OnConferenceRoomPlayWaveDone(Params[0] {const WideString},
                                     Params[1] {Integer});

    35: OnCallSessionConnecting(Params[0] {Integer},
                                Params[1] {Integer},
                                Params[2] {Integer},
                                Params[3] {const WideString});

    36: OnCallSessionLost(Params[0] {Integer},
                          Params[1] {Integer});

    37: OnCallSessionHangup(Params[0] {Integer},
                            Params[1] {Integer});

    38: OnCallSessionTimeout(Params[0] {Integer},
                             Params[1] {Integer});

    39: OnCallSessionCancelled(Params[0] {Integer});

    40: OnCallSessionTransfering(Params[0] {Integer},
                                 Params[1] {Integer},
                                 Params[2] {Integer},
                                 Params[3] {Integer},
                                 Params[4] {const WideString});

    41: OnCallSessionTransferFailed(Params[0] {Integer},
                                    Params[1] {Integer},
                                    Params[2] {Integer},
                                    Params[3] {Integer},
                                    Params[4] {const WideString});

    42: OnCallSessionTransferTimeout(Params[0] {Integer},
                                     Params[1] {Integer},
                                     Params[2] {Integer});

    43: OnCallSessionTransfered(Params[0] {Integer},
                                Params[1] {Integer});

    44: OnCallSessionCreated(Params[0] {Integer},
                             Params[1] {Integer});

    45: OnCallSessionDetectedAMD(Params[0] {Integer},
                                 Params[1] {Integer},
                                 Params[2] {WordBool});

    46: OnBusyLampSubscribe(Params[0] {Integer},
                            Params[1] {const WideString},
                            Params[2] {const WideString},
                            Params[3] {const WideString},
                            Params[4] {Integer});

    47: OnBusyLampUnSubscribe(Params[0] {Integer},
                              Params[1] {const WideString},
                              Params[2] {const WideString},
                              Params[3] {const WideString},
                              Params[4] {Integer});

    48: OnBusyLampSubscribeSuccess(Params[0] {Integer},
                                   Params[1] {const WideString});

    49: OnBusyLampSubscribeFailed(Params[0] {Integer},
                                  Params[1] {const WideString});

    50: OnCallSessionRecordedPCM(Params[0] {Integer},
                                 Params[1] {Integer},
                                 Params[2] {Int64},
                                 Params[3] {Integer},
                                 Params[4] {Integer});

    51: OnConferenceRoomRecordedPCM(Params[0] {const WideString},
                                    Params[1] {Int64},
                                    Params[2] {Integer},
                                    Params[3] {Integer});

    52: OnVaxErrorLog(Params[0] {const WideString},
                      Params[1] {Integer},
                      Params[2] {const WideString});

    53: OnAddCallSessionToQueueSuccess(Params[0] {const WideString},
                                       Params[1] {Integer});

    54: OnAddCallSessionToQueueFailed(Params[0] {const WideString},
                                      Params[1] {Integer});

    55: OnVaxLicenseChannel(Params[0] {Integer},
                            Params[1] {Integer});

    56: OnAddCallSessionToRingGroupSuccess(Params[0] {const WideString},
                                           Params[1] {Integer});

    57: OnAddCallSessionToRingGroupFailed(Params[0] {const WideString},
                                          Params[1] {Integer});

    58: OnSendReqTransferCallTimeout(Params[0] {Integer},
                                     Params[1] {Integer});

    59: OnSendReqTransferCallAccepted(Params[0] {Integer},
                                      Params[1] {Integer});

    60: OnSendReqTransferCallFailed(Params[0] {Integer},
                                    Params[1] {Integer},
                                    Params[2] {Integer},
                                    Params[3] {const WideString});

    61: OnQualityReportPUBLISH(Params[0] {const WideString},
                               Params[1] {const WideString},
                               Params[2] {const WideString},
                               Params[3] {Integer});

    62: OnBusyLampSendStatus(Params[0] {const WideString},
                             Params[1] {const WideString},
                             Params[2] {Integer});

    63: OnServerConnectingREC(Params[0] {Integer},
                              Params[1] {Integer},
                              Params[2] {Integer},
                              Params[3] {const WideString});

    64: OnServerConnectedREC(Params[0] {Integer},
                             Params[1] {Integer});

    65: OnServerFailedREC(Params[0] {Integer},
                          Params[1] {Integer},
                          Params[2] {Integer},
                          Params[3] {const WideString});

    66: OnServerTimeoutREC(Params[0] {Integer},
                           Params[1] {Integer});

    67: OnServerHungupREC(Params[0] {Integer},
                          Params[1] {Integer});

    68: OnQueuePlayWaveStart(Params[0] {Integer},
                             Params[1] {const WideString},
                             Params[2] {Integer});

    69: OnQueuePlayWaveStop(Params[0] {Integer},
                            Params[1] {const WideString},
                            Params[2] {Integer});

    70: OnQueueAgentConnectStarted(Params[0] {const WideString},
                                   Params[1] {const WideString},
                                   Params[2] {Integer});

    71: OnQueueAgentConnectTrying(Params[0] {const WideString},
                                  Params[1] {const WideString},
                                  Params[2] {Integer},
                                  Params[3] {Integer},
                                  Params[4] {const WideString});

    72: OnQueueAgentConnectFailed(Params[0] {const WideString},
                                  Params[1] {const WideString},
                                  Params[2] {Integer},
                                  Params[3] {Integer},
                                  Params[4] {const WideString});

    73: OnQueueAgentConnectTimeout(Params[0] {const WideString},
                                   Params[1] {const WideString},
                                   Params[2] {Integer});

    74: OnQueueAgentConnectSuccess(Params[0] {const WideString},
                                   Params[1] {const WideString},
                                   Params[2] {Integer});

    75: OnChatStatusSendSubscribeSuccess(Params[0] {Integer});

    76: OnChatStatusSendSubscribeFailed(Params[0] {Integer},
                                        Params[1] {Integer},
                                        Params[2] {const WideString});

    77: OnSendNotifyMsgSuccess(Params[0] {Integer});
    78: OnSendNotifyMsgFailed(Params[0] {Integer},
                              Params[1] {Integer},
                              Params[2] {const WideString});
  end; {case DispID}
end;

        procedure TVaxServerCOM.SetLicenseKey(sLicenseKey: String);
        begin
            Assert(m_pVaxServerLibCOM <> Nil);   //m_pVaxServerLibCOM is not NULL
            inherited SetLicenseKey(sLicenseKey);
        end;

        function TVaxServerCOM.Initialize(sDomainRealm: String; sSIPListenIP: String; nSIPListenPort: Integer; sRTPListenIP: String; nRTPListenPort: Integer): Boolean;
        begin
            Assert(m_pVaxServerLibCOM <> Nil);   //m_pVaxServerLibCOM is not NULL
            Result := Boolean(inherited Initialize(sDomainRealm, sSIPListenIP, nSIPListenPort, sRTPListenIP, nRTPListenPort));
        end;

        procedure TVaxServerCOM.UnInitialize();
        begin
            Assert(m_pVaxServerLibCOM <> Nil);   //m_pVaxServerLibCOM is not NULL
            m_pVaxServerLibCOM.UnInitialize();
        end;

        function TVaxServerCOM.AddUser(sUserName: String; sPassword: String; sCodecList: String): Boolean;
        begin
            Result := Boolean(inherited AddUser(sUserName, sPassword, sCodecList));
        end;

        procedure TVaxServerCOM.RemoveUser(sUserName: String);
        begin
            inherited RemoveUser(sUserName);
        end;

        function TVaxServerCOM.AcceptRegister(nRegId: Integer): Boolean;
        begin
            Result := Boolean(inherited AcceptRegister(nRegId));
        end;

        function TVaxServerCOM.RejectRegister(nRegId: Integer; nStatusCode: Integer; sReasonPhrase: String): Boolean;
        begin
            Result := Boolean(inherited RejectRegister(nRegId, nStatusCode, sReasonPhrase));
        end;

        function TVaxServerCOM.AuthRegister(nRegId: Integer): Boolean;
        begin
            Result := Boolean(inherited AuthRegister(nRegId));
        end;

        function TVaxServerCOM.AddLine(sLineName: String; sDisplayName: String; sUserName: String; sAuthUser: String; sAuthPwd: String; sDomainRealm: String; sProxySIP: String; sOutboundProxySIP: String; sCodecList: String): Boolean;
        begin
            Result := Boolean(inherited AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sOutboundProxySIP, sCodecList));
        end;

        procedure TVaxServerCOM.RemoveLine(sLineName: String);
        begin
            inherited RemoveLine(sLineName);
        end;

        function TVaxServerCOM.RegisterLine(sLineName: String): Boolean;
        begin
            Result := Boolean(inherited RegisterLine(sLineName, 1800));
        end;

        function TVaxServerCOM.UnRegisterLine(sLineName: String): Boolean;
        begin
            Result := Boolean(inherited UnRegisterLine(sLineName));
        end;

        function TVaxServerCOM.AddDirectProxySIP(sProxyName: String; sAuthLogin: String; sAuthPwd: String; sDomainRealm: String; sProxyIP: String; nProxyPort: Integer; sCodecList: String): Boolean;
        begin
            Result := Boolean(inherited AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList));
        end;

        procedure TVaxServerCOM.RemoveDirectProxySIP(sProxyName: String);
        begin
            inherited RemoveDirectProxySIP(sProxyName);
        end;

        function TVaxServerCOM.AcceptCallSession(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nToPeerType: Integer; sToPeerName: String; nTimeout: Integer): Boolean;
        begin
            Result := Boolean(inherited AcceptCallSession(nSessionId, sCallerName, sCallerId, sDialNo, nToPeerType, sToPeerName, nTimeout));
        end;

        procedure TVaxServerCOM.RejectCallSession(nSessionId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
            inherited RejectCallSession(nSessionId, nStatusCode, sReasonPhrase);
        end;

        procedure TVaxServerCOM.CloseCallSession(nSessionId: Integer);
        begin
            inherited CloseCallSession(nSessionId);
        end;

        function TVaxServerCOM.DialCallSession(sCallerName: String; sCallerId: String; sDialNo: String; nToPeerType: Integer; sToPeerName: String; nTimeout: Integer): Integer;
        begin
            Result := inherited DialCallSession(sCallerName, sCallerId, sDialNo, nToPeerType, sToPeerName, nTimeout);
        end;

        function TVaxServerCOM.AcceptTransferBlind(nTransfererSessionId: Integer; sCallerName: String; sCallerId: String; sTransferTo: String; nToPeerType: Integer; sToPeerName: String; nTimeout: Integer): Boolean;
        begin
            Result := inherited AcceptTransferBlind(nTransfererSessionId, sCallerName, sCallerId, sTransferTo, nToPeerType, sToPeerName, nTimeout);
        end;

        function TVaxServerCOM.AcceptTransferConsult(nTransfererSessionId: Integer; nTransferToSessionId: Integer): Boolean;
        begin
            Result := inherited AcceptTransferConsult(nTransfererSessionId, nTransferToSessionId);
        end;

        procedure TVaxServerCOM.RejectTransfer(nSessionId: Integer);
        begin
            inherited RejectTransfer(nSessionId);
        end;

        function TVaxServerCOM.PlayWaveStartToCallSession(nSessionId: Integer; nChannelId: Integer; nWaveId: Integer; bLoopPlay: Boolean; nPlayPos: Integer): Boolean;
        begin
            Result := Boolean(inherited PlayWaveStartToCallSession(nSessionId, nChannelId, nWaveId, bLoopPlay, nPlayPos));
        end;

        procedure TVaxServerCOM.PlayWaveStopToCallSession(nSessionId: Integer; nChannelId: Integer; nWaveId: Integer);
        begin
            inherited PlayWaveStopToCallSession(nSessionId,  nChannelId, nWaveId);
        end;

        function TVaxServerCOM.RecordWaveStartToCallSession(nSessionId: Integer; nChannelId: Integer; sFileName: String): Boolean;
        begin
            Result := Boolean(inherited RecordWaveStartToCallSession(nSessionId, nChannelId, sFileName));
        end;

        procedure TVaxServerCOM.RecordWaveStopToCallSession(nSessionId: Integer; nChannelId: Integer);
        begin
            inherited RecordWaveStopToCallSession(nSessionId, nChannelId);
        end;

        function TVaxServerCOM.RecordWavePauseToCallSession(nSessionId: Integer; nChannelId: Integer; bEnable: Boolean): Boolean;
        begin
            Result := Boolean(inherited RecordWavePauseToCallSession(nSessionId, nChannelId, bEnable));
        end;

        function TVaxServerCOM.LoadWaveFile(sFileName: String): Integer;
        begin
            Result := Int32(inherited LoadWaveFile(sFileName));
        end;

        procedure TVaxServerCOM.UnLoadWaveFile(lWaveId: Integer);
        begin
            inherited UnLoadWaveFile(lWaveId);
        end;

        function TVaxServerCOM.LoadMusicHold(sFileName: String): Boolean;
        begin
            Result := Boolean(inherited LoadMusicHold(sFileName));
        end;

        procedure TVaxServerCOM.UnLoadMusicHold();
        begin
            inherited UnLoadMusicHold();
        end;

        function TVaxServerCOM.AcceptOnHoldRequest(nSessionId : Integer): Boolean;
        begin
            Result := Boolean(inherited AcceptOnHoldRequest(nSessionId));
        end;

        function TVaxServerCOM.AcceptOffHoldRequest(nSessionId: Integer): Boolean;
        begin
            Result := Boolean(inherited AcceptOffHoldRequest(nSessionId));
        end;

        function TVaxServerCOM.AcceptChatMessage(nChatMsgId: Integer; nToPeerType: Integer; sToPeerName: String): Boolean;
        begin
            Result := Boolean(inherited AcceptChatMessage(nChatMsgId, nToPeerType, sToPeerName));
        end;

        procedure TVaxServerCOM.RejectChatMessage(nChatMsgId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
            inherited RejectChatMessage(nChatMsgId, nStatusCode, sReasonPhrase);
        end;

        function TVaxServerCOM.AcceptChatStatusSubscribe(nStatusSubscribe: Integer; sMsgFrom: String; sMsgTo: String; nToPeerType: Integer; sToPeerName: String): Boolean;
        begin
            Result := Boolean(inherited AcceptChatStatusSubscribe(nStatusSubscribe, sMsgFrom, sMsgTo, nToPeerType, sToPeerName));
        end;

        procedure TVaxServerCOM.RejectChatStatusSubscribe(nStatusSubscribe: Integer; sMsgFrom: String; sMsgTo: String);
        begin
            inherited RejectChatStatusSubscribe(nStatusSubscribe, sMsgFrom, sMsgTo);
        end;

        function TVaxServerCOM.OpenConferenceRoom(sRoomName: String): Boolean;
        begin
            Result := Boolean(inherited OpenConferenceRoom(sRoomName));
        end;

        procedure TVaxServerCOM.CloseConferenceRoom(sRoomName: String);
        begin
            inherited CloseConferenceRoom(sRoomName);
        end;

        function TVaxServerCOM.AddCallSessionToConferenceRoom(sRoomName: String; nSessionId: Integer; nType: Integer): Boolean;
        begin
            Result := Boolean(inherited AddCallSessionToConferenceRoom(sRoomName, nSessionId, nType));
        end;

        function TVaxServerCOM.RemoveCallSessionFromConferenceRoom(nSessionId: Integer): Boolean;
        begin
            Result := Boolean(inherited RemoveCallSessionFromConferenceRoom(nSessionId));
        end;

        function TVaxServerCOM.PlayWaveStartToConferenceRoom(sRoomName: String; lWaveId: Integer; bLoop: Boolean; nPlayPos: Integer): Boolean;
        begin
            Result := Boolean(inherited PlayWaveStartToConferenceRoom(sRoomName, lWaveId, bLoop, nPlayPos));
        end;

        function TVaxServerCOM.PlayWaveStopToConferenceRoom(sRoomName: String; lWaveId: Integer): Boolean;
        begin
            Result := Boolean(inherited PlayWaveStopToConferenceRoom(sRoomName, lWaveId));
        end;

        function TVaxServerCOM.RecordWaveStartToConferenceRoom(sRoomName: String; sFileName: String): Boolean;
        begin
            Result := Boolean(inherited RecordWaveStartToConferenceRoom(sRoomName, sFileName));
        end;

        function TVaxServerCOM.RecordWaveStopToConferenceRoom(sRoomName: String): Boolean;
        begin
            Result := Boolean(inherited RecordWaveStopToConferenceRoom(sRoomName));
        end;

        function TVaxServerCOM.RecordWavePauseToConferenceRoom(sRoomName: String; bEnable: Boolean): Boolean;
        begin
            Result := Boolean(inherited RecordWavePauseToConferenceRoom(sRoomName, bEnable));
        end;

        function TVaxServerCOM.VoiceSessionLost(bEnable: Boolean; nTimeout: Integer): Boolean;
        begin
            Result := Boolean(inherited VoiceSessionLost(bEnable, nTimeout));
        end;

        function TVaxServerCOM.SendInfoVM(sUserLogin: String; nNewMsgCount: Integer; nOldMsgCount: Integer; bMsgWaiting: Boolean): Integer;
        begin
            Result := Integer(inherited SendInfoVM(sUserLogin, nNewMsgCount, nOldMsgCount, bMsgWaiting));
        end;

        function TVaxServerCOM.StartVaxTeleTick(nTickId: Integer; nElapse: Integer): Boolean;
        begin
            Result := Boolean(inherited StartVaxTeleTick(nTickId, nElapse));
        end;

        function TVaxServerCOM.StopVaxTeleTick(nTickId: Integer): Boolean;
        begin
            Result := Boolean(inherited StopVaxTeleTick(nTickId));
        end;

        function TVaxServerCOM.SetUserAgentName(sName: String): Boolean;
        begin
            Result := Boolean(inherited SetUserAgentName(sName));
        end;

        function TVaxServerCOM.GetUserAgentName(): String;
        begin
            Result := inherited GetUserAgentName();
        end;

        function TVaxServerCOM.SetSessionNameSDP(sName: String): Boolean;
        begin
            Result := Boolean(inherited SetSessionNameSDP(sName));
        end;

        function TVaxServerCOM.GetSessionNameSDP(): String;
        begin
            Result := inherited GetSessionNameSDP();
        end;

        function TVaxServerCOM.SendDTMFCallSession(nSessionId: Integer; nChannelId: Integer; nTypeDTMF: Integer; nDigit: Integer): Boolean;
        begin
            Result := Boolean(inherited SendDTMFCallSession(nSessionId, nChannelId, nTypeDTMF, nDigit));
        end;

        function TVaxServerCOM.DetectDigitDTMF(nSessionId: Integer; nChannelId: Integer; nTypeDTMF: Integer; bEnable: Boolean; nTimeout: Integer): Boolean;
        begin
            Result := Boolean(inherited DetectDigitDTMF(nSessionId, nChannelId,  nTypeDTMF, bEnable, nTimeout));
        end;

        function TVaxServerCOM.GetVaxErrorCode(): Integer;
        begin
            Result := Integer(inherited GetVaxErrorCode());
        end;

        function TVaxServerCOM.DialToneToCallSession(bEnable: Boolean; nSessionId: Integer; nWaveId: Integer): Boolean;
        begin
            Result := Boolean(inherited DialToneToCallSession(bEnable, nSessionId, nWaveId));
        end;

        function TVaxServerCOM.DiagnosticLogSIP(bInbound: Boolean; bOutbound: Boolean): Boolean;
        begin
            Result := Boolean(inherited DiagnosticLogSIP(bInbound, bOutbound));
        end;

        function TVaxServerCOM.AddRingGroup(sGroupName: String): Boolean;
        begin
            Result := Boolean(inherited AddRingGroup(sGroupName));
        end;

        procedure TVaxServerCOM.RemoveRingGroup(sGroupName: String);
        begin
           inherited RemoveRingGroup(sGroupName);
        end;

        function TVaxServerCOM.AddRingGroupAgent(sGroupName: String; sUserName: String): Boolean;
        begin
            Result := Boolean(inherited AddRingGroupAgent(sGroupName, sUserName));
        end;

        procedure TVaxServerCOM.RemoveRingGroupAgent(sGroupName: String; sUserName: String);
        begin
            inherited RemoveRingGroupAgent(sGroupName, sUserName);
        end;

        function TVaxServerCOM.SetRingGroupProcessMode(sGroupName: String; nModeId: Integer; nModeType: Integer): Boolean;
        begin
            Result := Boolean(inherited SetRingGroupProcessMode(sGroupName, nModeId, nModeType));
        end;

        function TVaxServerCOM.SetRingGroupAgentPriority(sGroupName: String; sUserName: String; nPriority: Integer): Boolean;
        begin
            Result := Boolean(inherited SetRingGroupAgentPriority(sGroupName, sUserName, nPriority));
        end;

        function TVaxServerCOM.AddCallSessionToRingGroup(sGroupName: String; sCallerName: String; sCallerId: String; nSessionId: Integer): WordBool;
        begin
            Result := Boolean(inherited AddCallSessionToRingGroup(sGroupName, sCallerName, sCallerId, nSessionId));
        end;

        function TVaxServerCOM.AddCallPickUpGroup(sGroupName: String): Boolean;
        begin
            Result := Boolean(inherited AddCallPickUpGroup(sGroupName));
        end;

        procedure TVaxServerCOM.RemoveCallPickUpGroup(sGroupName: String);
        begin
            inherited RemoveCallPickUpGroup(sGroupName);
        end;

        function TVaxServerCOM.AddCallPickUpGroupMember(sGroupName: String; sUserName: String): Boolean;
        begin
            Result := Boolean(inherited AddCallPickUpGroupMember(sGroupName, sUserName));
        end;

        procedure TVaxServerCOM.RemoveCallPickUpGroupMember(sGroupName: String; sUserName: String);
        begin
            inherited RemoveCallPickUpGroupMember(sGroupName, sUserName);
        end;

        function TVaxServerCOM.PickUpCall(nSessionId: Integer; sUserName: String): Boolean;
        begin
            Result := Boolean(inherited PickUpCall(nSessionId, sUserName));
        end;

        function TVaxServerCOM.ParkCallSession(nSessionId: Integer; nChannelId: Integer; nSlotId: Integer): Boolean;
        begin
            Result := Boolean(inherited ParkCallSession(nSessionId, nChannelId, nSlotId));
        end;

        function TVaxServerCOM.ConnectToParkedCallSession(nSessionId: Integer; nChannelId: Integer; nSlotId: Integer): Boolean;
        begin
            Result := Boolean(inherited ConnectToParkedCallSession(nSessionId, nChannelId, nSlotId));
        end;

        function TVaxServerCOM.AddQueue(sQueueName: String): Boolean;
        begin
            Result := Boolean(inherited AddQueue(sQueueName));
        end;

        procedure TVaxServerCOM.RemoveQueue(sQueueName: String);
        begin
            inherited RemoveQueue(sQueueName);
        end;

        function TVaxServerCOM.AddQueueAgent(sQueueName: String; sUserName: String): Boolean;
        begin
            Result := Boolean(inherited AddQueueAgent(sQueueName, sUserName));
        end;

        procedure TVaxServerCOM.RemoveQueueAgent(sQueueName: String; sUserName: String);
        begin
            inherited RemoveQueueAgent(sQueueName, sUserName);
        end;

        function TVaxServerCOM.SetQueueAgentPriority(sQueueName: String; sUserName: String; nPriority: Integer): Boolean;
        begin
            Result := Boolean(inherited SetQueueAgentPriority(sQueueName, sUserName, nPriority));
        end;

        function TVaxServerCOM.SetQueueAgentStatus(sQueueName: String; sAgentName: String; lStatusId: Integer): Boolean;
        begin
             Result := Boolean(inherited SetQueueAgentStatus(sQueueName, sAgentName, lStatusId));
        end;

        function TVaxServerCOM.SetQueueProcessMode(sQueueName: String; nModeId: Integer; nProcessModeType: Integer): Boolean;
        begin
            Result := Boolean(inherited SetQueueProcessMode(sQueueName, nModeId, nProcessModeType));
        end;

        function TVaxServerCOM.AddCallSessionToQueue(sQueueName: String; sCallerName: String; sCallerId: String; nSessionId: Integer; nTimeout: Integer): Boolean;
        begin
            Result := Boolean(inherited AddCallSessionToQueue(sQueueName, sCallerName, sCallerId, nSessionId, nTimeout));
        end;

        function TVaxServerCOM.AddStealthListener(nStealthSessionId: Integer; nCapturePeerType: Integer; sCapturePeerName: String; nListenType: Integer): Boolean;
        begin
            Result := Boolean(inherited AddStealthListener(nStealthSessionId, nCapturePeerType, sCapturePeerName, nListenType));
        end;

        function TVaxServerCOM.MoveCall(nSrcSessionId: Integer; nChannelId: Integer; nDscSessionId: Integer): Boolean;
        begin
            Result := Boolean(inherited MoveCall(nSrcSessionId, nChannelId, nDscSessionId));
        end;

        function TVaxServerCOM.ConnectToServerREC(nSessionId: Integer; nChannelId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nToPeerType: Integer; sToPeerName: String; nTimeout: Integer): Boolean;
        begin
          Result := Boolean(inherited ConnectToServerREC(nSessionId, nChannelId, sCallerName, sCallerId, sDialNo, nToPeerType, sToPeerName, nTimeout));
        end;

        function TVaxServerCOM.SetExtDataREC(nSessionId: Integer; nChannelId: Integer; sExtData: String): Boolean;
        begin
          Result := Boolean(Inherited SetExtDataREC(nSessionId, nChannelId, sExtData));
        end;

        function TVaxServerCOM.SendNotifyMsgSIP(sMsgFrom: String; sMsgTo: String; sToPeerType: Integer; sToPeerName: String): Integer;
        begin
          Result := Integer(Inherited SendNotifyMsgSIP(sMsgFrom, sMsgTo, sToPeerType, sToPeerName));
        end;

        {///////////////////////////////////////////////////////////////////////////////
        ///////////////////     Events
        ///////////////////////////////////////////////////////////////////////////////}

        procedure TVaxServerCOM.OnLineRegisterTrying(sLineName: String);
        begin
        end;
        procedure TVaxServerCOM.OnLineRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String);
        begin
        end;
        procedure TVaxServerCOM.OnLineRegisterSuccess(sLineName: String);
        begin
        end;
        procedure TVaxServerCOM.OnLineUnRegisterTrying(sLineName: String);
        begin
        end;
        procedure TVaxServerCOM.OnLineUnRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String);
        begin
        end;
        procedure TVaxServerCOM.OnLineUnRegisterSuccess(sLineName: String);
        begin
        end;

        procedure TVaxServerCOM.OnUnRegisterUser(sUserLogin: String);
        begin
        end;

        procedure TVaxServerCOM.OnRegisterUser(sUserLogin: String; sDomain: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnRegisterUserSuccess(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnRegisterUserFailed(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnChatMessageText(nChatMsgId: Integer; sMsgFrom: String; sMsgTo: String; sMsgText: String; nFromPeerType: Integer; sFromPeerName: String; sFromIP: String; nFromPort: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnChatMessageTyping(nChatMsgId: Integer; sMsgFrom: String; sMsgTo: String; bIsTypingStart: Boolean; nFromPeerType: Integer; sFromPeerName: String; sFromIP: String; nFromPort: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnChatStatusSubscribe(nSubscrbId: Integer; sMsgFrom: String; sMsgTo: String; nFromPeerType: Integer; sFromPeerName: String; sFromIP: String; nFromPort: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnChatMessageSuccess(nChatMsgId: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnChatMessageFailed(nChatMsgId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
        end;
        procedure TVaxServerCOM.OnChatMessageTimeout(nChatMsgId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnCallSessionFailed(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
        end;
        procedure TVaxServerCOM.OnCallSessionConnected(nSessionId: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnCallSessionClosed(nSessionId: Integer; nChannelId: Integer; nReasonCode: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnCallSessionConnecting(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
        end;
        procedure TVaxServerCOM.OnCallSessionLost(nSessionId: Integer; nChannelId: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnCallSessionHangup(nSessionId: Integer; nChannelId: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnCallSessionTimeout(nSessionId: Integer; nChannelId: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnCallSessionCancelled(nSessionId: Integer);
        begin
        end;


        procedure TVaxServerCOM.OnCallSessionOnHold(nSessionId: Integer; nChannelId: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnCallSessionOffHold(nSessionId: Integer; nChannelId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String);
        begin
        end;
        procedure TVaxServerCOM.OnCallSessionTransferConsult(nTransfererSessionId: Integer; nTransfererChannelId: Integer; nTransferToSessionId: Integer; nTransferToChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String);
        begin
        end;

        procedure TVaxServerCOM.OnCallSessionTransfering(nSessionId: Integer; nTransferType: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
        end;

        procedure TVaxServerCOM.OnCallSessionTransferFailed(nSessionId: Integer; nTransferType: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
        end;

        procedure TVaxServerCOM.OnCallSessionTransferTimeout(nSessionId: Integer; nTransferType: Integer; nChannelId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnCallSessionTransfered(nSessionId: Integer; nTransferType: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnDetectedDigitDTMF(nSessionId: Integer; nChannelId: Integer; sDigitDTMF: String);
        begin
        end;

        procedure TVaxServerCOM.OnOutgoingDiagnosticLog(sMsgSIP: String; sToIP: String; nToPort: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnIncomingDiagnosticLog(sMsgSIP: String; sFromIP: String; nFromPort: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnVaxTeleTick(nTickId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnSendTimeoutVM(nMsgIdVM: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnSendSuccessVM(nMsgIdVM: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnCallSessionDialToneStart(nSessionId: Integer; nChannelId: Integer; nWaveId: Integer);
        begin
        end;
        procedure TVaxServerCOM.OnCallSessionDialToneStop(nSessionId: Integer; nChannelId: Integer; nWaveId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnBusyLampSubscribe(nSubscrbId: Integer; sUserName: String; sToUserName: String; sFromIP: String; nFromPort: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnBusyLampUnSubscribe(nSubscrbId: Integer; sUserName: String; sToUserName: String; sFromIP: String; nFromPort: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnBusyLampSubscribeSuccess(nSubscrbId: Integer; sUserName: String);
        begin
        end;

        procedure TVaxServerCOM.OnBusyLampSubscribeFailed(nSubscrbId: Integer; UserName: String);
        begin
        end;

        procedure TVaxServerCOM.OnBusyLampSendStatus(sFromUserName: String; sToUserName: String; nStateId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnCallSessionPlayWaveDone(nSessionId: Integer; nChannelId: Integer; nWaveId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnConferenceRoomPlayWaveDone(sRoomName: String; nWaveId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnCallSessionCreated(nSessionId: Integer; nChannelId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnCallSessionDetectedAMD(nSessionId: Integer; nChannelId: Integer; bIsHuman: Boolean);
        begin
        end;

        procedure TVaxServerCOM.OnCallSessionRecordedPCM(nSessionId: Integer; nChannelId: Integer; nDataPCM: Int64; nSizePCM: Integer; nTypePCM: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnConferenceRoomRecordedPCM(sRoomName: String; nDataPCM: Int64; nSizePCM: Integer; nTypePCM: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnVaxErrorLog(sFuncName: String; nErrorCode: Integer; sErrorMsg: String);
        begin
        end;

        procedure TVaxServerCOM.OnAddCallSessionToQueueSuccess(sQueueName: String; nSessionId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnAddCallSessionToQueueFailed(sQueueName: String; nSessionId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnVaxLicenseChannel(nTotalChannels: Integer; nUsedChannels: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnAddCallSessionToRingGroupSuccess(sGroupName: String; nSessionId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnAddCallSessionToRingGroupFailed(sGroupName: String; nSessionId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnSendReqTransferCallTimeout(nSessionId: Integer; nChannelId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnSendReqTransferCallAccepted(nSessionId: Integer; nChannelId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnSendReqTransferCallFailed(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
        end;

        procedure TVaxServerCOM.OnQualityReportPUBLISH(sMsgSIP: String; sMsgSDP: String; sFromIP: String; nFromPort: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnServerConnectingREC(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
        end;

        procedure TVaxServerCOM.OnServerConnectedREC(nSessionId: Integer; nChannelId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnServerFailedREC(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
        end;

        procedure TVaxServerCOM.OnServerTimeoutREC(nSessionId: Integer; nChannelId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnServerHungupREC(nSessionId: Integer; nChannelId: Integer);
        begin
        end;

        procedure TVaxServerCOM.OnQueuePlayWaveStart(nEventType: Integer; sQueueName: String; nSessionId: Integer);
        begin

        end;

        procedure TVaxServerCOM.OnQueuePlayWaveStop(nEventType: Integer; sQueueName: String; nSessionId: Integer);
        begin

        end;

        procedure TVaxServerCOM.OnQueueAgentConnectStarted(sQueueName: String; sAgentName: String; nSessionId: Integer);
        begin

        end;

        procedure TVaxServerCOM.OnQueueAgentConnectTrying(sQueueName: String; sAgentName: String; nSessionId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin

        end;

        procedure TVaxServerCOM.OnQueueAgentConnectFailed(sQueueName: String; sAgentName: String; nSessionId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin

        end;

        procedure TVaxServerCOM.OnQueueAgentConnectTimeout(sQueueName: String; sAgentName: String; nSessionId: Integer);
        begin

        end;

        procedure TVaxServerCOM.OnQueueAgentConnectSuccess(sQueueName: String; sAgentName: String; nSessionId: Integer);
        begin

        end;

        procedure TVaxServerCOM.OnChatStatusSendSubscribeSuccess(nSubscrbId: Integer);
        begin

        end;

        procedure TVaxServerCOM.OnChatStatusSendSubscribeFailed(nSubscrbId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin

        end;

        procedure TVaxServerCOM.OnSendNotifyMsgSuccess(nMsgId: Integer);
        begin

        end;

        procedure TVaxServerCOM.OnSendNotifyMsgFailed(nMsgId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin

        end;

end.

