unit VaxServerExCOM;

interface

uses

    VaxServerCOM,
    VaxDefine,
    VaxCallSessionRoute,

    System.Variants,
    System.SysUtils,
    System.Classes;

type TVaxServerExCOM = class(TVaxServerCOM)

        public

        class var mVaxExCOM: TVaxServerExCOM;
        m_objRouteCallSIP: TVaxCallSessionRoute;

        /////////////////////////////////////////////////////////////////////////////////////////////////
        ///     Data Members
        /////////////////////////////////////////////////////////////////////////////////////////////////

        private
        const LINE_NAME_REC = 'LineServerREC';

        private

        m_nRegisteredUserCount: Integer;
        m_bIsActivatedREC: Boolean;

        m_nMusicCallParkId: Integer;
        m_nDialToneId: Integer;

        {///////////////////////////////////////////////////////////////////////////////
        ///////////////////     Functions
        ///////////////////////////////////////////////////////////////////////////////}

        public

        constructor Create();

        function Initialize(sDomainRealm: String; sSIPListenIP: String; nSIPListenPort: Integer; sRTPListenIP: String; nRTPListenPort: Integer ): Boolean;
        procedure UnInitialize();

        /////////////////////////////// User Operations //////////////////////////////////////////
        ///
        function AddUser(sLogin, sPassword, sCodecList: String; bBlocked: Boolean; sUserPrefix, sDialPrefix: String; nToPeerType: Integer; sToPeerName: String): Boolean;
        procedure RemoveUser(sLogin: String);

        function IsUserExist(sLogin: String): Boolean;
        function IsUserBlocked(sLogin: String): Boolean;

        procedure GetUserAll(var objLoginList: TStringList);
        function GetUserDetails(sLogin: String; var sPassword, sCodecList: String; var bBlocked: Boolean; var sUserPrefix, sDialPrefix: String; var nToPeerType: Integer; var sToPeerName: String): Boolean;

        function GetRegUserCount(): Integer;
        function GetCallCount(): Integer;

        //////////////////////////// Line Operations /////////////////////////////////////////////////
        ///
        function AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList: String; bRegister: Boolean; nToPeerType: Integer; sToPeerName: String; bBlocked, bRejected: Boolean; sRoomName: String; sQueueName :string; sRingGroupName: String): Boolean;
        procedure RemoveLine(sLineName: String);

        function GetLineAll(var objLineList: TStringList): Boolean;
        function GetLineDetails(sLineName: String; var sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxyIP: String; var sCodecList: String; var bRegister: Boolean; var nToPeerType: Integer; sToPeerName: String; var bBlocked: Boolean; var sRoomName: String; var sRingGroupName: String; var sQueueName: String): Boolean;

        ////////////////////////// Proxy Operations /////////////////////////////////////////////////

        function AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP: String; nProxyPort: Integer; sCodecList: String; nToPeerType: Integer; sToPeerName: String; bBlocked: Boolean; sRoomName: String; sRingGroupName: String; sQueueName: String): Boolean;
        procedure RemoveDirectProxySIP(sProxyName: String);

        function GetDirectProxyAll(var pProxyList: TStringList): Boolean;
        function GetDirectProxyDetails(sProxyName: String; var sAuthLogin: String; var sAuthPwd: String; var sDomainRealm: String; var sProxyIP: String; var nProxyPort: Integer; var sCodecList: String; var nToPeerType: Integer; var sToPeerName: String; var bBlocked: Boolean; var sRoomName: String; var sRingGroupName: String; var sQueueName: String): Boolean;

        ///////////////////////// Call Session OPerations ///////////////////////////////////////////

        function AcceptCallSession(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nToPeerType: Integer; sToPeerName: String): Boolean;

        function AddRoom(sRoomName: String; sRoomNo: String): Boolean;
        procedure RemoveRoom(sRoomName: String);

        function GetRoomName(sRoomNo: String): String;
        function GetRoomDetails(sRoomName: String; var sRoomNo: String): Boolean;

        function IsRoomNoExist(sRoomNo: String): Boolean;
        function GetRoomAll(var pRoomList: TStringList): Boolean;

        function AddRingGroup(sGroupName: String): Boolean;
        procedure RemoveRingGroup(sGroupName: String);

        function GetRingGroupList(var sRingGroupList: TStringList): Boolean;
        function GetRingGroupAgentList(sGroupName: String; var sRingGroupAgentList: TStringList): Boolean;
        function GetRingGroupDetails(sGroupName: String; var nModeId: Integer; var nModeType: Integer; var sRingGroupAgentList: TStringList): Boolean;

        function AddRingGroupAgent(sGroupName: String; sUserName: String): Boolean;
        procedure RemoveRingGroupAgent(sGroupName: String; sUserName: String);

        function SetRingGroupProcessMode(sGroupName: String; nModeId: Integer; nModeType: Integer): Boolean;

        function AddCallPickUpGroup(sGroupName: String): Boolean;
        procedure RemoveCallPickUpGroup(sGroupName: String);

        function GetPickGroupList(var sPickGroupList: TStringList): Boolean;
        function GetPickUpGroupAgentList(sGroupName: String; var sPickGroupAgentList: TStringList): Boolean;

        function GetCallPickUpGroupName(sAgentName: String): String;

        function AddCallPickUpGroupMember(sGroupName: String; sUserName: String): Boolean;
        procedure RemoveCallPickUpGroupMember(sGroupName: String; sUserName: String);

        function AddQueue(sQueueName: String): Boolean;
        procedure RemoveQueue(sQueueName: String);

        function GetQueueList(var objStringList: TStringList): Boolean;
        function GetQueueDetails(sQueueName: String; var nModeId: Integer; var nModetype: Integer; var objAgentList: TStringList): Boolean;

        function AddQueueAgent(sQueueName: String; sUserName: String): Boolean;
        procedure RemoveQueueAgent(sQueueName: String; sUserName: String);
        function SetQueueProcessMode(sQueueName: String; nModeId: Integer; nProcessModeType: Integer): Boolean;

        function IsLineREC(sLineName: String): Boolean;
        procedure DeactivateREC;
        function ActivateREC(sAuthLogin: String; sAuthPwd: String; sProxySIP: String; bRegister: Boolean): Boolean;
        function IsActivatedREC(): Boolean;

        /////////////////////////////////////// Call Session Route Operations /////////////////////////////////////////////////

        function AddUserRoute(sUserName, sUserPrefix, sDialPrefix: String; nToPeerType: Integer; sToPeerName: String): Boolean;
        procedure RemoveUserRoute(sUserName: String);

        function AddLineRoute(sLineName: String; nToPeerType: Integer; sToPeerName: String; bRejected: Boolean; sRoomName: String; sQueueName :string; sRingGroupName: String): Boolean;
        procedure RemoveLineRoute(sLineName: String);

        function AddDirectProxyRoute(sProxyName: String; nToPeerType: Integer; sToPeerName: String; bRejected: Boolean; sRoomName: String; sQueueName :string; sRingGroupName: String): Boolean;
        procedure RemoveDirectProxyRoute(sProxyName: String);

        function GetFromPeerRouteInfo(nFromPeerType: Integer; sDialNo: String; sFromPeerName: String; var sToPeerName: String; var sDialToNo: String; var sRoomName:string; var sRingGroupName: String; var sQueueName: String; var nToPeerType: Integer; var bRejected: Boolean) : Boolean;

        function GetUserRouteInfo(sUserName: String; sUserDialedNo: String; var sDialNo: String; var nToPeerType: Integer; var sToPeerName: String): Boolean;
        function GetLineRouteInfo(sLineName: String; var nToPeerType: Integer; var sToPeerName: String; var bRejected: Boolean; var sRoomName: String; var sQueueName: String; var sRingGroupName: String): Boolean;
        function GetProxyRouteInfo(sProxyName: String; var nToPeerType: Integer; var sToPeerName: String; var bRejected: Boolean; var sRoomName: String; var sQueueName: String; var sRingGroupName: String): Boolean;

        function DialToneToCallSession(bEnable: Boolean; nSessionId: Integer) : Boolean;

        function GetCallParkMusicId() : Integer;
        function LoadMusicCallPark(sFileName: String) : Boolean;
        procedure UnLoadMusicCallPark();

        function GetMusicDialToneId() : Integer;
        function LoadMusicDialTone(sFileName: String) : Boolean;
        procedure UnLoadMusicDialTone();

        /////////////////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////////////////

        public

        procedure OnLineRegisterTrying(sLineName: String); override;
        procedure OnLineRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String); override;
        procedure OnLineRegisterSuccess(sLineName: String); override;

        procedure OnLineUnRegisterTrying(sLineName: String); override;
        procedure OnLineUnRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String); override;
        procedure OnLineUnRegisterSuccess(sLineName: String); override;

        procedure OnLineRegisterTryingREC(sLineName: String); virtual;
        procedure OnLineRegisterFailedREC(sLineName: String; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnLineRegisterSuccessREC(sLineName: String); virtual;

        procedure OnLineUnRegisterTryingREC(sLineName: String); virtual;
        procedure OnLineUnRegisterFailedREC(sLineName: String; nStatusCode: Integer; sReasonPhrase: String); virtual;
        procedure OnLineUnRegisterSuccessREC(sLineName: String); virtual;

        procedure OnUnRegisterUser(sUserLogin: String); override;
        procedure OnRegisterUser(sUserLogin: String; sDomain: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); override;
        procedure OnRegisterUserSuccess(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); override;
        procedure OnRegisterUserFailed(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer); override;

        procedure OnChatMessageText(nChatMsgId: Integer; sMsgFrom: String; sMsgTo: String; sMsgText: String; nFromPeerType: Integer; sFromPeerName: String; sFromIP: String; nFromPort: Integer); override;
        procedure OnChatMessageTyping(nChatMsgId: Integer; sMsgFrom: String; sMsgTo: String; bIsTypingStart: Boolean; nFromPeerType: Integer; sFromPeerName: String; sFromIP: String; nFromPort: Integer); override;
        procedure OnChatStatusSubscribe(nSubscrbId: Integer; sMsgFrom: String; sMsgTo: String; nFromPeerType: Integer; sFromPeerName: String; sFromIP: String; nFromPort: Integer); override;

        procedure OnChatMessageSuccess(nChatMsgId: Integer); override;
        procedure OnChatMessageFailed(nChatMsgId: Integer; nStatusCode: Integer; sReasonPhrase: String); override;
        procedure OnChatMessageTimeout(nChatMsgId: Integer); override;

        procedure OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer); override;
        procedure OnCallSessionFailed(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String); override;
        procedure OnCallSessionConnected(nSessionId: Integer); override;

        procedure OnCallSessionConnecting(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String); override;
        procedure OnCallSessionLost(nSessionId: Integer; nChannelId: Integer); override;
        procedure OnCallSessionHangup(nSessionId: Integer; nChannelId: Integer); override;
        procedure OnCallSessionTimeout(nSessionId: Integer; nChannelId: Integer); override;
        procedure OnCallSessionCancelled(nSessionId: Integer); override;

        procedure OnCallSessionOnHold(nSessionId: Integer; nChannelId: Integer); override;
        procedure OnCallSessionOffHold(nSessionId: Integer; nChannelId: Integer); override;

        procedure OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String); override;
        procedure OnCallSessionTransferConsult(nTransfererSessionId: Integer; nTransfererChannelId: Integer; nTransferToSessionId: Integer; nTransferToChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String); override;

        procedure OnCallSessionTransfering(nSessionId: Integer; nTransferType: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String); override;
        procedure OnCallSessionTransfered(nSessionId: Integer; nTransferType: Integer); override;

        procedure OnDetectedDigitDTMF(nSessionId: Integer; nChannelId: Integer; sDigitDTMF: String); override;
        procedure OnOutgoingDiagnosticLog(sMsgSIP: String; sToIP: String; nToPort: Integer); override;
        procedure OnIncomingDiagnosticLog(sMsgSIP: String; sFromIP: String; nFromPort: Integer); override;

        procedure OnVaxTeleTick(nTickId: Integer); override;

        procedure OnSendTimeoutVM(nMsgIdVM: Integer); override;
        procedure OnSendSuccessVM(nMsgIdVM: Integer); override;

        procedure OnBusyLampSubscribe(nSubscrbId: Integer; sUserName: String; sToUserName: String; sFromIP: String; nFromPort: Integer); override;
        procedure OnBusyLampUnSubscribe(nSubscrbId: Integer; sUserName: String; sToUserName: String; sFromIP: String; nFromPort: Integer); override;
        procedure OnBusyLampSubscribeSuccess(nSubscrbId: Integer; sUserName: String); override;
        procedure OnBusyLampSubscribeFailed(nSubscrbId: Integer; UserName: String); override;
        procedure OnBusyLampSendStatus(sFromUserName: String; sToUserName: String; nStateId: Integer); override;

        procedure OnCallSessionCreated(nSessionId: Integer; nChannelId: Integer); override;
        procedure OnCallSessionClosed(nSessionId: Integer; nChannelId: Integer; nReasonCode: Integer); override;

        procedure OnCallSessionDetectedAMD(nSessionId: Integer; nChannelId: Integer; bIsHuman: Boolean); override;
        procedure OnVaxErrorLog(sFuncName: String; nErrorCode: Integer; sErrorMsg: String); override;

        procedure OnAddCallSessionToQueueSuccess(sQueueName: String; nSessionId: Integer); override;
        procedure OnAddCallSessionToQueueFailed(sQueueName: String; nSessionId: Integer); override;

        procedure OnAddCallSessionToRingGroupSuccess(sGroupName: String; nSessionId: Integer); override;
        procedure OnAddCallSessionToRingGroupFailed(sGroupName: String; nSessionId: Integer); override;

        procedure OnStatusLog(sStatus: String); virtual;
        procedure OnErrorLog(sError: String); virtual;

end;

implementation

uses

    VaxChat,
    VaxDirectProxy,
    VaxUser,
    VaxCallSession,
    VaxLine,
    VaxCallPickUpList,
    VaxRingGroupList,
    VaxQueueList,
    VaxRoomList;

var

    m_objVaxChat: TVaxChat;

    m_objQueueList: TVaxQueueList;
    m_objPickUpList: TVaxPickUpList;
    m_objRingGroupList: TVaxRingGroupList;

    m_objConfRoomList: TVaxRoomList;

    {///////////////////////////////////////////////////////////////////////////////
    ///////////////////     Functions    ///////////////////////////////////////////
    ///////////////////////////////////////////////////////////////////////////////}

      constructor TVaxServerExCOM.Create();
      begin

        inherited Create();

        mVaxExCOM := self;

        m_bIsActivatedREC := False;
        m_nRegisteredUserCount := 0;

        m_nMusicCallParkId := -1;
        m_nDialToneId := -1;

        m_objVaxChat := TVaxChat.Create();

        m_objQueueList := TVaxQueueList.Create();
        m_objPickUpList := TVaxPickUpList.Create();
        m_objRingGroupList := TVaxRingGroupList.Create();

        m_objConfRoomList := TVaxRoomList.Create();
        m_objRouteCallSIP := TVaxCallSessionRoute.Create();

      end;

      function TVaxServerExCOM.Initialize(sDomainRealm: String; sSIPListenIP: String; nSIPListenPort: Integer; sRTPListenIP: String; nRTPListenPort: Integer ): Boolean;
      begin

        UnInitialize();
        m_nRegisteredUserCount := 0;

        Result := inherited;

      end;

      procedure TVaxServerExCOM.UnInitialize();
      begin
        inherited;
      end;

      function TVaxServerExCOM.AddUser(sLogin, sPassword, sCodecList: String; bBlocked: Boolean; sUserPrefix, sDialPrefix: String; nToPeerType: Integer; sToPeerName: String): Boolean;
      var
        objUser: TVaxUser;
      begin

        if(Length(sUserPrefix) = 0 ) then
        begin

          if(Length(sDialPrefix) = 0) then
            sToPeerName := '';

        end;

        AddUserRoute(sLogin, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);

        objUser := TVaxUser.Create();
        objUser.SetData(sLogin, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);

        Result := Inherited AddUser(sLogin, sPassword, sCodecList);
        if(Result = False) Then Exit(False);

         Result := inherited SetUserData(sLogin, Int64(objUser));
      end;

      procedure TVaxServerExCOM.RemoveUser(sLogin: String);
      var
        objUser: TVaxUser;
      begin

        objUser := TVaxUser(inherited GetUserData(sLogin));
        if(objUser = nil) Then Exit();

        RemoveUserRoute(slogin);
        inherited RemoveUser(sLogin);

      end;


      function TVaxServerExCOM.IsUserExist(sLogin: String): Boolean;
      var
        objUser: TVaxUser;
      begin

       objUser := TVaxUser(inherited GetUserData(sLogin));
       if(objUser = nil) Then Exit(False);

       Result := True;

      end;

      function TVaxServerExCOM.IsUserBlocked(sLogin: String): Boolean;
      var
        objUser: TVaxUser;
      begin

        objUser := TVaxUser(inherited GetUserData(sLogin));
        if(objUser = nil) Then Exit(False);

        Result := objUser.IsUserBlocked();

      end;

      procedure TVaxServerExCOM.GetUserAll(var objLoginList: TStringList);
      var
      sLoginName: String;
      begin

        TrvsUserStart();
        sLoginName := TrvsUserNext();

        while sLoginName <> '' do
        begin
          objLoginList.Add(sLoginName);
          sLoginName := TrvsUserNext();
        end;

      end;

      function TVaxServerExCOM.GetUserDetails(sLogin: String; var sPassword, sCodecList: String; var bBlocked: Boolean; var sUserPrefix, sDialPrefix: String; var nToPeerType: Integer; var sToPeerName: String): Boolean;
      var
        objUser: TVaxUser;
      begin

        objUser := TVaxUser(inherited GetUserData(sLogin));
        if(objUser = nil) Then Exit(False);

        Result := objUser.GetUserDetails(sLogin, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);

      end;

      function TVaxServerExCOM.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList: String; bRegister: Boolean; nToPeerType: Integer; sToPeerName: String; bBlocked, bRejected: Boolean; sRoomName: String; sQueueName :string; sRingGroupName: String): Boolean;
      var
        objLine: TVaxLine;
      begin

        AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);

        objLine := TVaxLine(inherited GetLineData(sLineName));
        if(objLine = nil) Then objLine := TVaxLine.Create();

        Result := inherited AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sProxySIP, sCodecList);

        if(Result = False) Then
            Exit(False);

        objLine.SetData(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlocked, sRoomName, sRingGroupName, sQueueName);
        Result :=  SetLineData(sLineName, Int64(objLine));

      end;

      procedure TVaxServerExCOM.RemoveLine(sLineName: String);
      var
        objLine: TVaxLine;
      begin

        objLine := TVaxLine(inherited GetLineData(sLineName));
        if(objLine = nil) Then Exit();

        inherited RemoveLine(sLineName);

      end;

      function TVaxServerExCOM.GetLineAll(var objLineList: TStringList): Boolean;
      var
        sLineName: String;
      begin

        TrvsDirectProxyStart();
        sLineName := TrvsDirectProxyNext();

        while sLineName <> '' do
        begin
          objLineList.Add(sLineName);
          sLineName := TrvsDirectProxyNext();
        end;

        Result := True;

      end;

      function TVaxServerExCOM.GetLineDetails(sLineName: String; var sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxyIP: String; var sCodecList: String; var bRegister: Boolean; var nToPeerType: Integer; sToPeerName: String; var bBlocked: Boolean; var sRoomName: String; var sRingGroupName: String; var sQueueName: String): Boolean;
      var
        objLine: TVaxLine;
      begin

        objLine := TVaxLine(inherited GetLineData(sLineName));
        if(objLine = nil) Then Exit(False);

        Result := objLine.GetData(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxyIP, sCodecList, bRegister, nToPeerType, sToPeerName, bBlocked, sRoomName, sRingGroupName, sQueueName);

      end;

      function TVaxServerExCOM.AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP: String; nProxyPort: Integer; sCodecList: String; nToPeerType: Integer; sToPeerName: String; bBlocked: Boolean; sRoomName: String; sRingGroupName: String; sQueueName: String): Boolean;
      var
        objDirectProxy: TVaxDirectProxy;
      begin

        objDirectProxy := TVaxDirectProxy(inherited GetDirectProxyData(sProxyName));

        if(objDirectProxy = nil) Then
          objDirectProxy := TVaxDirectProxy.Create();

        Result := inherited AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList);
        if(Result = False) Then Exit(False);

        objDirectProxy.SetData(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList, nToPeerType, sToPeerName, bBlocked, sRoomName, sRingGroupName, sQueueName);
        Result := inherited SetDirectProxyData(sProxyName, Int64(objDirectProxy));

      end;

      procedure TVaxServerExCOM.RemoveDirectProxySIP(sProxyName: String);
      begin
        inherited;
      end;

      function TVaxServerExCOM.GetDirectProxyAll(var pProxyList: TStringList): Boolean;
      var
        sProxyName: String;
      begin

        TrvsDirectProxyStart();
        sProxyName := TrvsDirectProxyNext();

        while sProxyName <> '' do
        begin
          pProxyList.Add(sProxyName);
          sProxyName := TrvsDirectProxyNext();
        end;

        Result := True;

      end;

      function TVaxServerExCOM.GetDirectProxyDetails(sProxyName: String; var sAuthLogin: String; var sAuthPwd: String; var sDomainRealm: String; var sProxyIP: String; var nProxyPort: Integer; var sCodecList: String; var nToPeerType: Integer; var sToPeerName: String; var bBlocked: Boolean; var sRoomName: String; var sRingGroupName: String; var sQueueName: String): Boolean;
      var
        objDirectProxy: TVaxDirectProxy;
      begin

        objDirectProxy := TVaxDirectProxy(inherited GetDirectProxyData(sProxyName));
        if(objDirectProxy = nil) Then Exit(False);

        Result := objDirectProxy.GetData(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList, nToPeerType, sToPeerName, bBlocked, sRoomName, sRingGroupName, sQueueName);

      end;

      function TVaxServerExCOM.AcceptCallSession(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nToPeerType: Integer; sToPeerName: String): Boolean;
      begin

        Result := inherited AcceptCallSession(nSessionId, sCallerName, sCallerId, sDialNo, nToPeerType, sToPeerName, 20);
        if Result = False then Exit(False);

        if IsActivatedREC() then
        begin
          Result := inherited ConnectToServerREC(nSessionId, 0, sCallerName, sCallerId, sDialNo, TVaxServerCOM.VAX_PEER_TYPE_LINE, LINE_NAME_REC, 30);
          if Result = False then Exit(False);
        end;

        Result := True;

      end;

      function TVaxServerExCOM.AddRoom(sRoomName: String; sRoomNo: String): Boolean;
      begin

        if(m_objConfRoomList.AddRoom(sRoomName, sRoomNo) = False) then
          Exit(False);

        if(inherited OpenConferenceRoom(sRoomName) = False) then
          Exit(False);

        Result := True;

      end;

      procedure TVaxServerExCOM.RemoveRoom(sRoomName: String);
      begin
        m_objConfRoomList.RemoveRoom(sRoomName);
        inherited CloseConferenceRoom(sRoomName);
      end;

      function TVaxServerExCOM.GetRoomName(sRoomNo: String): String;
      begin
        Result := m_objConfRoomList.GetRoomName(sRoomNo);
      end;

      function TVaxServerExCOM.GetRoomDetails(sRoomName: String; var sRoomNo: String): Boolean;
      begin
        Result := m_objConfRoomList.GetRoomDetails(sRoomName, sRoomNo);
      end;

      function TVaxServerExCOM.IsRoomNoExist(sRoomNo: String): Boolean;
      begin
        Result := m_objConfRoomList.IsRoomNoExist(sRoomNo);
      end;

      function TVaxServerExCOM.GetRoomAll(var pRoomList: TStringList): Boolean;
      begin
        Result := m_objConfRoomList.GetRoomAll(pRoomList);
      end;

      function TVaxServerExCOM.AddRingGroup(sGroupName: String): Boolean;
      begin
        m_objRingGroupList.AddRingGroup(sGroupName);
        Result := inherited;
      end;

      procedure TVaxServerExCOM.RemoveRingGroup(sGroupName: String);
      begin
        m_objRingGroupList.RemoveRingGroup(sGroupName);
        inherited;
      end;

      function TVaxServerExCOM.GetRingGroupList(var sRingGroupList: TStringList): Boolean;
      begin
        Result := m_objRingGroupList.GetRingGroupNameList(sRingGroupList);
      end;

      function TVaxServerExCOM.GetRingGroupAgentList(sGroupName: String; var sRingGroupAgentList: TStringList): Boolean;
      begin
        Result := m_objRingGroupList.GetRingGroupAgentList(sGroupName, sRingGroupAgentList);
      end;

      function TVaxServerExCOM.GetRingGroupDetails(sGroupName: String; var nModeId: Integer; var nModeType: Integer; var sRingGroupAgentList: TStringList): Boolean;
      begin
        Result := m_objRingGroupList.GetRingGroupDetails(sGroupName, nModeId, nModeType, sRingGroupAgentList);
      end;

      function TVaxServerExCOM.AddRingGroupAgent(sGroupName: String; sUserName: String): Boolean;
      begin
        m_objRingGroupList.AddRingGroupMember(sGroupName, sUserName);
        Result := inherited;
      end;

      procedure TVaxServerExCOM.RemoveRingGroupAgent(sGroupName: String; sUserName: String);
      begin
        m_objRingGroupList.RemoveRingGroupAgent(sGroupName, sUserName);
        inherited;
      end;

      function TVaxServerExCOM.SetRingGroupProcessMode(sGroupName: String; nModeId: Integer; nModeType: Integer): Boolean;
      begin
        m_objRingGroupList.SetRingGroupProcessMode(sGroupName, nModeId, nModeType);
        Result := inherited;
      end;

      function TVaxServerExCOM.AddCallPickUpGroup(sGroupName: String): Boolean;
      begin
        m_objPickUpList.AddPickUp(sGroupName);
        Result :=inherited;
      end;

      procedure TVaxServerExCOM.RemoveCallPickUpGroup(sGroupName: String);
      begin
        m_objPickUpList.RemovePickUp(sGroupName);
        inherited;
      end;

      function TVaxServerExCOM.GetPickGroupList(var sPickGroupList: TStringList): Boolean;
      begin
        Result := m_objPickUpList.GetPickUpGroupList(sPickGroupList);
      end;

      function TVaxServerExCOM.GetPickUpGroupAgentList(sGroupName: String; var sPickGroupAgentList: TStringList): Boolean;
      begin
        Result := m_objPickUpList.GetPickUpGroupAgentList(sGroupName, sPickGroupAgentList);
      end;

      function TVaxServerExCOM.GetCallPickUpGroupName(sAgentName: String): String;
      begin
        Result := m_objPickUpList.GetCallPickUpGroupName(sAgentName);
      end;

      function TVaxServerExCOM.AddCallPickUpGroupMember(sGroupName: String; sUserName: String): Boolean;
      begin
        m_objPickUpList.AddPickUpAgent(sGroupName, sUserName);
        Result := inherited;
      end;

      procedure TVaxServerExCOM.RemoveCallPickUpGroupMember(sGroupName: String; sUserName: String);
      begin
        m_objPickUpList.RemovePickUpAgent(sGroupName, sUserName);
        inherited;
      end;

      function TVaxServerExCOM.AddQueue(sQueueName: String): Boolean;
      begin
        m_objQueueList.AddQueue(sQueueName);
        Result := inherited AddQueue(sQueueName);
      end;

      procedure TVaxServerExCOM.RemoveQueue(sQueueName: String);
      begin
        m_objQueueList.RemoveQueue(sQueueName);
        inherited RemoveQueue(sQueueName);
      end;

      function TVaxServerExCOM.GetQueueList(var objStringList: TStringList): Boolean;
      begin
        Result := m_objQueueList.GetQueueNameList(objStringList);
      end;

      function TVaxServerExCOM.GetQueueDetails(sQueueName: String; var nModeId: Integer; var nModetype: Integer; var objAgentList: TStringList): Boolean;
      begin
        Result := m_objQueueList.GetQueueAgentDetails(sQueueName, nModeId, nModetype, objAgentList);
      end;

      function TVaxServerExCOM.AddQueueAgent(sQueueName: String; sUserName: String): Boolean;
      begin
        m_objQueueList.AddQueueAgent(sQueueName, sUserName);
        Result := inherited AddQueueAgent(sQueueName, sUserName);;
      end;

      procedure TVaxServerExCOM.RemoveQueueAgent(sQueueName: String; sUserName: String);
      begin
        m_objQueueList.RemoveQueueAgent(sQueueName, sUserName);
        inherited RemoveQueueAgent(sQueueName, sUserName);
      end;

      function TVaxServerExCOM.SetQueueProcessMode(sQueueName: String; nModeId: Integer; nProcessModeType: Integer): Boolean;
      begin
        m_objQueueList.SetQueueProcessMode(sQueueName, nModeId, nProcessModeType);
        Result := inherited SetQueueProcessMode(sQueueName, nModeId, nProcessModeType);
      end;

      //////////////////////////////////////////////////////////////////////////////////
      //////////////////////////////////////////////////////////////////////////////////

      function TVaxServerExCOM.IsLineREC(sLineName: String): Boolean;
      begin
        Result := (sLineName = LINE_NAME_REC);
      end;

      procedure  TVaxServerExCOM.DeactivateREC;
      begin
        inherited UnRegisterLine(LINE_NAME_REC);
        m_bIsActivatedREC := False;
      end;

      function TVaxServerExCOM.ActivateREC(sAuthLogin: String; sAuthPwd: String; sProxySIP: String; bRegister: Boolean): Boolean;
      begin

        inherited RemoveLine(LINE_NAME_REC);

        Result := inherited AddLine(LINE_NAME_REC, sAuthLogin, sAuthLogin, sAuthLogin, sAuthPwd, sProxySIP, sProxySIP, '', '32041');
        if(Result = false) then Exit;

         if(bRegister = true) then
            Result := inherited RegisterLine(LINE_NAME_REC);

         m_bIsActivatedREC := True;

      end;

      function  TVaxServerExCOM.IsActivatedREC: Boolean;
      begin
        Result := m_bIsActivatedREC;
      end;

      //////////////////////////////////////////////////////////////////////////////////
      //////////////////////////////////////////////////////////////////////////////////

      function TVaxServerExCOM.AddUserRoute(sUserName, sUserPrefix, sDialPrefix: String; nToPeerType: Integer; sToPeerName: String): Boolean;
      begin
        Result := m_objRouteCallSIP.AddUserRoute(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
      end;

      procedure TVaxServerExCOM.RemoveUserRoute(sUserName: String);
      begin
        m_objRouteCallSIP.RemoveUserRoute(sUserName);
      end;

      function TVaxServerExCOM.AddLineRoute(sLineName: String; nToPeerType: Integer; sToPeerName: String; bRejected: Boolean; sRoomName: String; sQueueName :string; sRingGroupName: String): Boolean;
      begin
        Result := m_objRouteCallSIP.AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
      end;

      procedure TVaxServerExCOM.RemoveLineRoute(sLineName: String);
      begin
        m_objRouteCallSIP.RemoveLineRoute(sLineName);
      end;

      function TVaxServerExCOM.AddDirectProxyRoute(sProxyName: String; nToPeerType: Integer; sToPeerName: String; bRejected: Boolean; sRoomName: String; sQueueName :string; sRingGroupName: String): Boolean;
      begin
        Result := m_objRouteCallSIP.AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
      end;

      procedure TVaxServerExCOM.RemoveDirectProxyRoute(sProxyName: String);
      begin
        m_objRouteCallSIP.RemoveDirectProxyRoute(sProxyName);
      end;

      function TVaxServerExCOM.GetFromPeerRouteInfo(nFromPeerType: Integer; sDialNo: String; sFromPeerName: String; var sToPeerName: String; var sDialToNo: String; var sRoomName:string; var sRingGroupName: String; var sQueueName: String; var nToPeerType: Integer; var bRejected: Boolean) : Boolean;
      begin

        if(nFromPeerType = TVaxServerCOM.VAX_PEER_TYPE_USER) Then
        begin

          if(IsRoomNoExist(sDialNo)) then
          begin
            sRoomName := GetRoomName(sDialNo);
            Exit(True);
          end;

          GetUserRouteInfo(sFromPeerName, sDialNo, sDialToNo, nToPeerType, sToPeerName);

        end
        else
        begin

          if(nFromPeerType = TVaxServerCOM.VAX_PEER_TYPE_LINE) Then
          begin
            GetLineRouteInfo(sFromPeerName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
          end
          else
          begin
            if(nFromPeerType = TVaxServerCOM.VAX_PEER_TYPE_DIRECT_PROXY) Then
              GetProxyRouteInfo(sFromPeerName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
          end;

        end;

         Exit(True);

       end;

      function TVaxServerExCOM.GetUserRouteInfo(sUserName: String; sUserDialedNo: String; var sDialNo: String; var nToPeerType: Integer; var sToPeerName: String): Boolean;
      begin
        Result := m_objRouteCallSIP.GetUserRouteInfo(sUserName, sUserDialedNo, sDialNo, nToPeerType, sToPeerName);
      end;

      function TVaxServerExCOM.GetLineRouteInfo(sLineName: String; var nToPeerType: Integer; var sToPeerName: String; var bRejected: Boolean; var sRoomName: String; var sQueueName: String; var sRingGroupName: String): Boolean;
      begin
        Result := m_objRouteCallSIP.GetLineRouteInfo(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
      end;

      function TVaxServerExCOM.GetProxyRouteInfo(sProxyName: String; var nToPeerType: Integer; var sToPeerName: String; var bRejected: Boolean; var sRoomName: String; var sQueueName: String; var sRingGroupName: String): Boolean;
      begin
        Result := m_objRouteCallSIP.GetProxyRouteInfo(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
      end;

      function TVaxServerExCOM.GetRegUserCount(): Integer;
      begin
        Result := m_nRegisteredUserCount;
      end;

      function TVaxServerExCOM.GetCallCount(): Integer;
      begin
        Result := inherited GetCallCount();
      end;

      function TVaxServerExCOM.DialToneToCallSession(bEnable: Boolean; nSessionId: Integer) : Boolean;
      begin

        if(m_nDialToneId = -1) then
          Exit(True);

        Result := inherited DialToneToCallSession(bEnable, nSessionId, m_nDialToneId);

      end;

      function TVaxServerExCOM.LoadMusicDialTone(sFileName : string) : Boolean;
      begin

        UnLoadMusicDialTone();

        m_nDialToneId := inherited LoadWaveFile(sFileName);

        if(m_nDialToneId = -1) Then
          Exit(False);

        Result := True;

      end;

      procedure TVaxServerExCOM.UnLoadMusicDialTone();
      begin

        if(m_nDialToneId <> -1) Then
        begin

          UnLoadWaveFile(m_nDialToneId);
          m_nDialToneId := -1;

        end;

      end;

      function TVaxServerExCOM.GetMusicDialToneId() : Integer;
      begin
        Result := m_nDialToneId;
      end;


      function TVaxServerExCOM.LoadMusicCallPark(sFileName : String) : Boolean;
      begin

        UnLoadMusicCallPark();

        m_nMusicCallParkId := inherited LoadWaveFile(sFileName);
        if(m_nMusicCallParkId = -1) Then Exit(False);

        Result := True;

      end;

      procedure TVaxServerExCOM.UnLoadMusicCallPark();
      begin

        if(m_nMusicCallParkId <> -1) Then
        begin

          UnLoadWaveFile(m_nMusicCallParkId);
          m_nMusicCallParkId := -1;

        end;

      end;

      function TVaxServerExCOM.GetCallParkMusicId() : Integer;
      begin
        Result := m_nMusicCallParkId;
      end;

      ////////////////////////////////////////////////////////////////////////////////
      ////////////////////////////////////////////////////////////////////////////////
      ////////////////////////////////////////////////////////////////////////////////
      ////////////////////////////////////////////////////////////////////////////////
      ////////////////////////////////////////////////////////////////////////////////
      ////////////////////////////////////////////////////////////////////////////////
      ////////////////////////////////////////////////////////////////////////////////

        // Line Events

        procedure TVaxServerExCOM.OnLineRegisterTrying(sLineName: String);
        var
         objLine: TVaxLine;

        begin

            if (IsLineREC(sLineName)) then
            begin
               OnLineRegisterTryingREC(sLineName);
               Exit
            end;

            objLine := TVaxLine(inherited GetLineData(sLineName));

            if(objLine = nil) Then
              Exit();

              objLine.OnLineRegisterTrying(sLineName);
        end;

        procedure TVaxServerExCOM.OnLineRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String);
        var

        objLine: TVaxLine;

        begin

          if (IsLineREC(sLineName)) then
          begin
            OnLineRegisterFailedREC(sLineName, nStatusCode, sReasonPhrase);
            Exit
          end;

          objLine := TVaxLine(inherited GetLineData(sLineName));

          if(objLine = nil) Then
            Exit();

          objLine.OnLineRegisterFailed(sLineName, nStatusCode, sReasonPhrase);

        end;

        procedure TVaxServerExCOM.OnLineRegisterSuccess(sLineName: String);
        var

        objLine: TVaxLine;

        begin

          if (IsLineREC(sLineName)) then
          begin
            OnLineRegisterSuccessREC(sLineName);
            Exit
          end;

          objLine := TVaxLine(inherited GetLineData(sLineName));

          if(objLine = nil) Then
            Exit();

          objLine.OnLineRegisterSuccess(sLineName);

        end;

        procedure TVaxServerExCOM.OnLineUnRegisterTrying(sLineName: String);
        var

        objLine: TVaxLine;

        begin

          if (IsLineREC(sLineName)) then
          begin
            OnLineUnRegisterTryingREC(sLineName);
            Exit
          end;

          objLine := TVaxLine(inherited GetLineData(sLineName));

          if(objLine = nil) Then
            Exit();

          objLine.OnLineUnRegisterTrying(sLineName);

        end;

        procedure TVaxServerExCOM.OnLineUnRegisterFailed(sLineName: String; nStatusCode: Integer; sReasonPhrase: String);
        var

        objLine: TVaxLine;

        begin

          if (IsLineREC(sLineName)) then
          begin
            OnLineUnRegisterFailedREC(sLineName, nStatusCode, sReasonPhrase);
            Exit
          end;

          objLine := TVaxLine(inherited GetLineData(sLineName));

          if(objLine = nil) Then
            Exit();

          objLine.OnLineUnRegisterFailed(sLineName, nStatusCode, sReasonPhrase);
        end;

        procedure TVaxServerExCOM.OnLineUnRegisterSuccess(sLineName: String);
        var

        objLine: TVaxLine;

        begin

          if (IsLineREC(sLineName)) then
          begin
            OnLineUnRegisterSuccessREC(sLineName);
            Exit
          end;

          objLine := TVaxLine(inherited GetLineData(sLineName));

          if(objLine = nil) Then
            Exit();

          objLine.OnLineUnRegisterSuccess(sLineName);

        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnLineRegisterTryingREC(sLineName: String);
        begin
        end;

        procedure TVaxServerExCOM.OnLineRegisterFailedREC(sLineName: String; nStatusCode: Integer; sReasonPhrase: String);
        begin
        end;

        procedure TVaxServerExCOM.OnLineRegisterSuccessREC(sLineName: String);
        begin
        end;

        procedure TVaxServerExCOM.OnLineUnRegisterTryingREC(sLineName: String);
        begin
        end;

        procedure TVaxServerExCOM.OnLineUnRegisterFailedREC(sLineName: String; nStatusCode: Integer; sReasonPhrase: String);
        begin
        end;

        procedure TVaxServerExCOM.OnLineUnRegisterSuccessREC(sLineName: String);
        begin
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnUnRegisterUser(sUserLogin: String);
        var
         objUser: TVaxUser;
        begin
          objUser := TVaxUser(inherited GetUserData(sUserLogin));
          if(objUser = nil) Then Exit();

          if objUser.IsUserRegistered() = True then
            m_nRegisteredUserCount := m_nRegisteredUserCount - 1;

          objUser.OnUnRegisterUser(sUserLogin);
        end;

        procedure TVaxServerExCOM.OnRegisterUser(sUserLogin: String; sDomain: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
        var
          objUser: TVaxUser;
        begin
          objUser := TVaxUser(inherited GetUserData(sUserLogin));

          if(objUser = nil) Then
          begin
            inherited RejectRegister(nRegId, 404, TVaxDefine.NOT_FOUND);
            Exit();
          end;

          objUser.OnRegisterUser(sUserLogin, sDomain, sUserAgentName, sFromIP, nFromPort, nRegId);
        end;

        procedure TVaxServerExCOM.OnRegisterUserSuccess(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
        var
          objUser: TVaxUser;
        begin
          objUser := TVaxUser(inherited GetUserData(sUserLogin));
          if(objUser = nil) Then Exit();

          if objUser.IsUserRegistered() = false then
            m_nRegisteredUserCount := m_nRegisteredUserCount + 1;

          objUser.OnRegisterUserSuccess(sUserLogin);
        end;

        procedure TVaxServerExCOM.OnRegisterUserFailed(sUserLogin: String; sFromIP: String; nFromPort: Integer; nRegId: Integer);
        var
          objUser: TVaxUser;
        begin
          objUser := TVaxUser(inherited GetUserData(sUserLogin));
          if(objUser = nil) Then Exit();

          objUser.OnRegisterUserFailed(sUserLogin);
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnChatMessageText(nChatMsgId: Integer; sMsgFrom: String; sMsgTo: String; sMsgText: String; nFromPeerType: Integer; sFromPeerName: String; sFromIP: String; nFromPort: Integer);
        begin
          m_objVaxChat.OnChatMessageText(nChatMsgId, sMsgFrom, sMsgTo, sMsgText, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
        end;

        procedure TVaxServerExCOM.OnChatMessageTyping(nChatMsgId: Integer; sMsgFrom: String; sMsgTo: String; bIsTypingStart: Boolean; nFromPeerType: Integer; sFromPeerName: String; sFromIP: String; nFromPort: Integer);
        begin
          m_objVaxChat.OnChatMessageTyping(nChatMsgId, sMsgFrom, sMsgTo, bIsTypingStart, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
        end;
        procedure TVaxServerExCOM.OnChatStatusSubscribe(nSubscrbId: Integer; sMsgFrom: String; sMsgTo: String; nFromPeerType: Integer; sFromPeerName: String; sFromIP: String; nFromPort: Integer);
        begin
          m_objVaxChat.OnChatStatusSubscribe(nSubscrbId, sMsgFrom, sMsgTo, nFromPeerType, sFromPeerName, sFromIP, nFromPort);
        end;

        procedure TVaxServerExCOM.OnChatMessageSuccess(nChatMsgId: Integer);
        begin
          m_objVaxChat.OnChatMessageSuccess(nChatMsgId);
        end;

        procedure TVaxServerExCOM.OnChatMessageFailed(nChatMsgId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        begin
            m_objVaxChat.OnChatMessageFailed(nChatMsgId, nStatusCode, sReasonPhrase);
        end;

        procedure TVaxServerExCOM.OnChatMessageTimeout(nChatMsgId: Integer);
        begin
            m_objVaxChat.OnChatMessageTimeout(nChatMsgId);
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnIncomingCall(nSessionId: Integer; sCallerName: String; sCallerId: String; sDialNo: String; nFromPeerType: Integer; sFromPeerName: String; sUserAgentName: String; sFromIP: String; nFromPort: Integer);
        var
          objCallSession: TVaxCallSession;

          sToPeerName: String; sDialToNo: String;
          sRoomName: String; sRingGroupName: String;
          sQueueName: String;

          nToPeerType: Integer;
          bRejected: Boolean;
        begin

          GetFromPeerRouteInfo(nFromPeerType, sDialNo, sFromPeerName, sToPeerName, sDialToNo, sRoomName, sRingGroupName, sQueueName, nToPeerType, bRejected);

          if(bRejected = True) then
          begin

            RejectCallSession(nSessionId, 404, 'Not Found');
            Exit();

          end;

          DialToneToCallSession(True, nSessionId);

          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnIncomingCall(nSessionId, sCallerName, sCallerId, sDialNo, sRoomName, sQueueName, sRingGroupName, nFromPeerType, sFromPeerName, nToPeerType, sToPeerName, sUserAgentName, sFromIP, nFromPort);
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnCallSessionConnecting(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionConnecting(nSessionId, nChannelId, nStatusCode, sReasonPhrase);
        end;

        procedure TVaxServerExCOM.OnCallSessionFailed(nSessionId: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionFailed(nSessionId, nChannelId, nStatusCode, sReasonPhrase);
        end;

        procedure TVaxServerExCOM.OnCallSessionConnected(nSessionId: Integer);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionConnected(nSessionId);
        end;

        procedure TVaxServerExCOM.OnCallSessionLost(nSessionId: Integer; nChannelId: Integer);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionLost(nSessionId, nChannelId);
        end;

        procedure TVaxServerExCOM.OnCallSessionHangup(nSessionId: Integer; nChannelId: Integer);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionHangup(nSessionId, nChannelId);
        end;

        procedure TVaxServerExCOM.OnCallSessionTimeout(nSessionId: Integer; nChannelId: Integer);
        var
          objCallSession: TVaxCallSession;
        begin
         objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionTimeout(nSessionId, nChannelId);
        end;

        procedure TVaxServerExCOM.OnCallSessionCancelled(nSessionId: Integer);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionCancelled(nSessionId);
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnCallSessionOnHold(nSessionId: Integer; nChannelId: Integer);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionOnHold(nSessionId, nChannelId);
        end;

        procedure TVaxServerExCOM.OnCallSessionOffHold(nSessionId: Integer; nChannelId: Integer);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionOffHold(nSessionId, nChannelId);
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnCallSessionTransferBlind(nTransfererSessionId: Integer; nTransfererChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nTransfererSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionTransferBlind(nTransfererSessionId, nTransfererChannelId, sTransferer, sTransferee, sTransferTo);
        end;

        procedure TVaxServerExCOM.OnCallSessionTransferConsult(nTransfererSessionId: Integer; nTransfererChannelId: Integer; nTransferToSessionId: Integer; nTransferToChannelId: Integer; sTransferer: String; sTransferee: String; sTransferTo: String);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nTransfererSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionTransferConsult(nTransfererSessionId, nTransfererChannelId, nTransferToSessionId, nTransferToChannelId, sTransferer, sTransferee, sTransferTo);
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnCallSessionTransfering(nSessionId: Integer; nTransferType: Integer; nChannelId: Integer; nStatusCode: Integer; sReasonPhrase: String);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionTransfering(nSessionId, nTransferType, nChannelId, nStatusCode, sReasonPhrase);
        end;

        procedure TVaxServerExCOM.OnCallSessionTransfered(nSessionId: Integer; nTransferType: Integer);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionTransfered(nSessionId, nTransferType);
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnDetectedDigitDTMF(nSessionId: Integer; nChannelId: Integer; sDigitDTMF: String);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnDetectedDigitDTMF(nSessionId, nChannelId, sDigitDTMF);
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnOutgoingDiagnosticLog(sMsgSIP: String; sToIP: String; nToPort: Integer);
        begin
        end;

        procedure TVaxServerExCOM.OnIncomingDiagnosticLog(sMsgSIP: String; sFromIP: String; nFromPort: Integer);
        begin
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnVaxTeleTick(nTickId: Integer);
        begin
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnSendTimeoutVM(nMsgIdVM: Integer);
        begin
        end;

        procedure TVaxServerExCOM.OnSendSuccessVM(nMsgIdVM: Integer);
        begin
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnCallSessionCreated(nSessionId: Integer; nChannelId: Integer);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession.Create();
          inherited SetCallSessionData(nSessionId, Int64(objCallSession));
        end;

        procedure TVaxServerExCOM.OnCallSessionClosed(nSessionId: Integer; nChannelId: Integer; nReasonCode: Integer);
        var
          objCallSession: TVaxCallSession;
        begin
          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnCallSessionClosed(nSessionId, nChannelId, nReasonCode);
        end;

 /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnCallSessionDetectedAMD(nSessionId: Integer; nChannelId: Integer; bIsHuman: Boolean);
        var
          objCallSession: TVaxCallSession;
        begin

          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil)  Then Exit();

          objCallSession.OnCallSessionDetectedAMD(nSessionId, nChannelId, bIsHuman);

        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        procedure TVaxServerExCOM.OnBusyLampSubscribe(nSubscrbId: Integer; sUserName: String; sToUserName: String; sFromIP: String; nFromPort: Integer);
        begin
          BusyLampSubscribeAccept(nSubscrbId, True, 30)
        end;

        procedure TVaxServerExCOM.OnBusyLampUnSubscribe(nSubscrbId: Integer; sUserName: String; sToUserName: String; sFromIP: String; nFromPort: Integer);
        begin
        end;

        procedure TVaxServerExCOM.OnBusyLampSubscribeSuccess(nSubscrbId: Integer; sUserName: String);
        begin
        end;

        procedure TVaxServerExCOM.OnBusyLampSubscribeFailed(nSubscrbId: Integer; UserName: String);
        begin
        end;

        procedure TVaxServerExCOM.OnBusyLampSendStatus(sFromUserName: String; sToUserName: String; nStateId: Integer);
        begin
          BusyLampSendStatus(sFromUserName, sToUserName, nStateId);
        end;

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

       procedure TVaxServerExCOM.OnVaxErrorLog(sFuncName: String; nErrorCode: Integer; sErrorMsg: String);
          var sMsg: String;
       begin
          sMsg := '[Method: ' + sFuncName + '] [Error Msg: ' + sErrorMsg + '] [Code: ' + IntToStr(nErrorCode) + ']';
          OnErrorLog(sMsg);
       end;

       procedure TVaxServerExCOM.OnAddCallSessionToQueueSuccess(sQueueName: String; nSessionId: Integer);
       var
          objCallSession: TVaxCallSession;
       begin

          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil) Then Exit();

          objCallSession.OnAddCallSessionToQueueSuccess(sQueueName, nSessionId);

       end;

       /////////////////////////////////////////////////////////////////////////
       /////////////////////////////////////////////////////////////////////////

       procedure TVaxServerExCOM.OnAddCallSessionToQueueFailed(sQueueName: String; nSessionId: Integer);
       var
          objCallSession: TVaxCallSession;
       begin

          objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
          if(objCallSession = nil)  Then Exit();

          objCallSession.OnAddCallSessionToQueueFailed(sQueueName, nSessionId);
       end;

       procedure TVaxServerExCOM.OnAddCallSessionToRingGroupSuccess(sGroupName: String; nSessionId: Integer);
       var
         objCallSession: TVaxCallSession;
       begin

         objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
         if(objCallSession = nil)  Then Exit();

         objCallSession.OnAddCallSessionToRingGroupSuccess(sGroupName, nSessionId);

       end;

       procedure TVaxServerExCOM.OnAddCallSessionToRingGroupFailed(sGroupName: String; nSessionId: Integer);
       var
         objCallSession: TVaxCallSession;
       begin

         objCallSession := TVaxCallSession(inherited GetCallSessionData(nSessionId));
         if(objCallSession = nil)  Then Exit();

         objCallSession.OnAddCallSessionToRingGroupFailed(sGroupName, nSessionId);

       end;

       /////////////////////////////////////////////////////////////////////////
       /////////////////////////////////////////////////////////////////////////

       procedure TVaxServerExCOM.OnStatusLog(sStatus: String);
       begin
       end;

       procedure TVaxServerExCOM.OnErrorLog(sError: String);
       begin
       end;
end.

