#include "StdAfx.h"
#include "RingGroupList.h"
#include "RingGroupUserList.h"


CRingGroupDetails::CRingGroupDetails()
{
	m_pRingGroupUserList = new CRingGroupUserList();

	m_nProcessMode = -1;
	m_nProcessType = -1;
}

CRingGroupDetails::~CRingGroupDetails()
{
	delete m_pRingGroupUserList;
}

/////////////////////////////////////////////////////////////////////////////////////////////
BOOL CRingGroupDetails::AddRingGroupAgent(LPCTSTR sAgentName)
{
	return  m_pRingGroupUserList->AddAgent(sAgentName);
}

void CRingGroupDetails::RemoveRingGroupAgent(LPCTSTR sAgentName)
{
	m_pRingGroupUserList->RemoveAgent(sAgentName);
}



/////////////////////////////////////////////////////////////////////////////////////////////

BOOL CRingGroupDetails::GetRingGroupAgentList(CStringList& sListAgentName)
{
	return m_pRingGroupUserList->GetRingGroupAgentList(sListAgentName);
}

int CRingGroupDetails::GetRingGroupAgentCount()
{
	return m_pRingGroupUserList->GetCount();
}

CString CRingGroupDetails::GetRingGroupAgentAt(int nIndex)
{
	return m_pRingGroupUserList->GetRingGroupAgentAt(nIndex);
}

/////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////

CRingGroupList::CRingGroupList(void)
{
	m_pRingGroupList = new CRingGroupListMap();
	m_pRingGroupList->InitHashTable(TRUE, 256);
}

CRingGroupList::~CRingGroupList(void)
{
	DeleteRingGroupAll();
	delete m_pRingGroupList;
}

/////////////////////////////////////////////////////////////////////////////////////////////

void CRingGroupList::DeleteRingGroupAll()
{
	CRingGroupDetails* pDetails = NULL;
	CString sKey;

	POSITION pPos = m_pRingGroupList->GetStartPosition();
	while(pPos != NULL)
	{
		m_pRingGroupList->GetNextAssoc(pPos, sKey, pDetails);
		delete pDetails;
	}

	m_pRingGroupList->RemoveAll();
}

CString CRingGroupList::GenKey(LPCTSTR sRingGroupName)
{
	return CString(sRingGroupName).MakeLower();
}

/////////////////////////////////////////////////////////////////////////////////////////////

CRingGroupDetails* CRingGroupList::FindRingGroup(LPCTSTR sRingGroupName)
{
	CRingGroupDetails* pDetails = NULL;
	
	CString sKey = GenKey(sRingGroupName);

	if(!m_pRingGroupList->Lookup(sKey, pDetails))
		return NULL;

	return pDetails;
}

/////////////////////////////////////////////////////////////////////////////////////////////

BOOL CRingGroupList::AddRingGroup(LPCTSTR sRingGroupName)
{
	if(CString(sRingGroupName).IsEmpty())
		return FALSE;
	
	if(FindRingGroup(sRingGroupName) != NULL)
		return FALSE;
	
	CRingGroupDetails* pDetails = new CRingGroupDetails();
	pDetails->m_sRingGroupName = sRingGroupName;

	m_pRingGroupList->SetAt(GenKey(sRingGroupName), pDetails);
	return TRUE;
}

void CRingGroupList::RemoveRingGroup(LPCTSTR sRingGroupName)
{
	CRingGroupDetails* pDetails = NULL;
	
	if(!m_pRingGroupList->Lookup(GenKey(sRingGroupName), pDetails))
		return;
	
	delete pDetails;
	m_pRingGroupList->RemoveKey(GenKey(sRingGroupName));
}

void CRingGroupList::SetRingGroupProcessMode(LPCTSTR sRingGroupName, int nProcessMode, int nProcessType)
{
	CRingGroupDetails* pDetails = NULL;
	
	if(!m_pRingGroupList->Lookup(GenKey(sRingGroupName), pDetails))
		return;

	if(pDetails == NULL)
		return;

	pDetails->m_nProcessMode = nProcessMode;
	pDetails->m_nProcessType = nProcessType;
}

BOOL CRingGroupList::GetRingGroupDetails(LPCTSTR sRingGroupName, int& nProcessMode, int& nProcessType, CStringList& sListAgentName)
{
	CRingGroupDetails* pDetails = NULL;
		
	if(!m_pRingGroupList->Lookup(GenKey(sRingGroupName), pDetails))
		return FALSE;

	if(pDetails == NULL)
		return FALSE;

	nProcessMode = pDetails->m_nProcessMode;
	nProcessType = pDetails->m_nProcessType;

	return pDetails->GetRingGroupAgentList(sListAgentName);
}

/////////////////////////////////////////////////////////////////////////////////////////////

BOOL CRingGroupList::AddRingGroupAgent(LPCTSTR sRingGroupName, LPCTSTR sAgentName)
{
	CRingGroupDetails* pDetails = NULL;
		
	if(!m_pRingGroupList->Lookup(GenKey(sRingGroupName), pDetails))
		return FALSE;
	
	return pDetails->AddRingGroupAgent(sAgentName);
}

void CRingGroupList::RemoveRingGroupAgent(LPCTSTR sRingGroupName, LPCTSTR sAgentName)
{
	CRingGroupDetails* pDetails = NULL;
		
	if(!m_pRingGroupList->Lookup(GenKey(sRingGroupName), pDetails))
		return;
		
	pDetails->RemoveRingGroupAgent(sAgentName);
}

/////////////////////////////////////////////////////////////////////////////////////////////

BOOL CRingGroupList::GetRingGroupList(CStringList& sListRingGroupName)
{
	POSITION posList =  m_pRingGroupList->GetStartPosition();
	
	CString sKey;
	CRingGroupDetails* pDetails;

	while(posList != NULL)
	{
		m_pRingGroupList->GetNextAssoc(posList, sKey, pDetails);
		sListRingGroupName.AddTail(pDetails->m_sRingGroupName);
	}

	return TRUE;
}

int CRingGroupList::GetRingGroupAgentCount(LPCTSTR sRingGroupName)
{
	CRingGroupDetails* pDetails = NULL;
		
	if(!m_pRingGroupList->Lookup(GenKey(sRingGroupName), pDetails))
		return TRUE;

	return pDetails->GetRingGroupAgentCount();
}

CString CRingGroupList::GetRingGroupAgentAt(LPCTSTR sRingGroupName, int nIndex)
{
	CRingGroupDetails* pDetails = NULL;
		
	if(!m_pRingGroupList->Lookup(GenKey(sRingGroupName), pDetails))
		return "";

	return pDetails->GetRingGroupAgentAt(nIndex);
}
