using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Collections.Generic;

using ServerSIP;

namespace VaxTeleConfigSIP
{
    public partial class LineForm : Form
    {
        private cVaxServerSIP m_objVaxTeleSIP;
        
        public LineForm(ref cVaxServerSIP objVaxServer)
        {
            InitializeComponent();
            
            m_objVaxTeleSIP = objVaxServer;
            RadioRejectCall.Checked = true;
        }

        private void LineForm_Load(object sender, EventArgs e)
        {
            LoadCodecs();
        }
 
        private void BtnAddLine_Click(object sender, EventArgs e)
        {
            if(AddLineChecks() == false)
                return;

            if(ComboLine.FindStringExact(ComboLine.Text) != -1)
            {
                if(MessageBox.Show("Line already exists, do you want to continue?", "VaxTeleSIP", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation) == DialogResult.No)
                {
                    return;
                }
            }

            cCodec objCodec = new cCodec();
            string sCodec = "";

            for(int nCount = 0; nCount < ListBoxEnableCodec.Items.Count; nCount++)
                sCodec += objCodec.GetCodecNo((string) ListBoxEnableCodec.Items[nCount]);

            ///////////////////////////////////////////////////////////////////////////////

            int nToPeerType = -1;
            string sToPeerName = "", sRoomName = "", sQueueName = "", sRingGroupName = "";
            bool bRejected = false;

            bRejected = RadioRejectCall.Checked;

            if(RadioConnectToUser.Checked)
            {
                nToPeerType = cVaxServerCOM.VAX_PEER_TYPE_USER;
                sToPeerName = ComboConnectToUser.Text.Trim().ToString();
            }
            else if(RadioPutInConf.Checked)
            {
                sRoomName = ComboPutInConf.Text.Trim().ToString();
            }
            else if(RbtnQueue.Checked)
            {
                sQueueName = comboQueueName.Text;
            }
            else if(RbtnRingGroup.Checked)
            {
                sRingGroupName = comboRingGroupName.Text;
            }

            ///////////////////////////////////////////////////////////////////////////////

            if(ComboLine.Items.Contains(ComboLine.Text))
                m_objVaxTeleSIP.RemoveLine(ComboLine.Text);

            if(m_objVaxTeleSIP.AddLine(ComboLine.Text, EditDisplayName.Text, EditUserName.Text, EditAuthUser.Text, EditPassword.Text, EditDomainRealm.Text, EditProxySIP.Text, sCodec, CheckBoxRegLine.Checked, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName) == false)
            {
                MessageBox.Show("Line could not be added or Please start the server first.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            if(!ComboLine.Items.Contains(ComboLine.Text))
                ComboLine.Items.Add(ComboLine.Text);

            MessageBox.Show("Line added/updated successfully.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
        }
               
        private void ClearDlgContent()
        {
            ComboLine.Text = "";

            EditUserName.Text = "";
            EditAuthUser.Text = "";
            EditPassword.Text = "";
            EditDisplayName.Text = "";
            EditDomainRealm.Text = "";
            EditProxySIP.Text = "";
            
            if(ComboConnectToUser.Items.Count > 0)
                ComboConnectToUser.SelectedIndex = 0;

            if(ComboPutInConf.Items.Count > 0)
                ComboPutInConf.SelectedIndex = 0;
            
            CheckBoxRegLine.Checked = false;

            ListBoxEnableCodec.Items.Clear();
            ListBoxDisableCodec.Items.Clear();

            ListBoxEnableCodec.Items.Add(cCodec.G711U_TEXT);
            ListBoxEnableCodec.Items.Add(cCodec.G711A_TEXT);
            ListBoxEnableCodec.Items.Add(cCodec.ILBC_TEXT);
            ListBoxEnableCodec.Items.Add(cCodec.G610_TEXT);
            ListBoxEnableCodec.Items.Add(cCodec.G729_TEXT);

            RadioRejectCall.Checked = true;
        }

        private void BtnRemoveLine_Click(object sender, EventArgs e)
        {
            if(ComboLine.Text.Length == 0)
            {
                MessageBox.Show("Please enter line name.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return;
            }

            int nIndex = ComboLine.FindStringExact(ComboLine.Text);
            if(nIndex == -1) return;

            m_objVaxTeleSIP.RemoveLine(ComboLine.Text);
            ComboLine.Items.RemoveAt(nIndex);

            ClearDlgContent();
            
            if (ComboLine.Items.Count > 0)
                ComboLine.SelectedIndex = 0;
                        
            ShowLineDetails();
            
            MessageBox.Show("Line removed successfully!", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
        }

        private void ComboLine_SelectedIndexChanged(object sender, EventArgs e)
        {
            ShowLineDetails();
        }

        private void BtnClearLineDlg_Click(object sender, EventArgs e)
        {
            ClearDlgContent();
        }

        private void BtnDisableCodec_Click(object sender, EventArgs e)
        {
            if(ListBoxEnableCodec.SelectedItems.Count == 0) return;

            ListBoxDisableCodec.Items.Add(ListBoxEnableCodec.SelectedItem.ToString());
            ListBoxEnableCodec.Items.Remove(ListBoxEnableCodec.SelectedItem);
        }

        private void BtnEnableCodec_Click(object sender, EventArgs e)
        {
            if(ListBoxDisableCodec.SelectedItems.Count == 0) return;

            ListBoxEnableCodec.Items.Add(ListBoxDisableCodec.SelectedItem.ToString());
            ListBoxDisableCodec.Items.Remove(ListBoxDisableCodec.SelectedItem);
        }

        private void LoadCodecs()
        {
            cCodec objCodec = new cCodec();

            for (int nCount = 0; nCount < cCodec.TOTAL_SIZE_CODEC; nCount++)
                ListBoxEnableCodec.Items.Add(objCodec.GetCodecName(Convert.ToString(nCount)));
        }

        private void AddLines()
        {
            ComboLine.Items.Clear();

            RadioRejectCall.Checked = true;

            ArrayList objListLines = new ArrayList();
            m_objVaxTeleSIP.GetLineAll(ref objListLines);

            if(objListLines.Count <= 0)
            {
                return;
            }

            for (int nCount = 0; nCount < objListLines.Count; nCount++)
                ComboLine.Items.Add(objListLines[nCount]);

            if(ComboLine.Items.Count > 0)
                ComboLine.SelectedIndex = 0;
        }

        private void AddQueues()
        {
            comboQueueName.Items.Clear();

            List<string> objListQueueName = new List<string>();
            m_objVaxTeleSIP.GetQueueNameAll(ref objListQueueName);

            if(objListQueueName.Count <= 0)
                return;

            foreach (string sQueueName in objListQueueName)
            {
                comboQueueName.Items.Add(sQueueName);
            }
           
            if(comboQueueName.Items.Count > 0)
               comboQueueName.SelectedIndex = 0;
        }

        private void AddRingGroups()
        {
            comboRingGroupName.Items.Clear();

            List<string> objListGroupName = new List<string>();
            m_objVaxTeleSIP.GetRingGroupNameAll(ref objListGroupName);

            if(objListGroupName.Count <= 0)
                return;

            foreach (string sRingGroupName in objListGroupName)
            {
                comboRingGroupName.Items.Add(sRingGroupName);
            }

            if(comboRingGroupName.Items.Count > 0)
                comboRingGroupName.SelectedIndex = 0;
        }

        private void AddUsers()
        {
            ComboConnectToUser.Items.Clear();
            
            ArrayList objListUsers = new ArrayList();
            m_objVaxTeleSIP.GetUserAll(ref objListUsers);

            if(objListUsers.Count <= 0) return;

            for (int nCount = 0; nCount < objListUsers.Count; nCount++)
                ComboConnectToUser.Items.Add(objListUsers[nCount]);

            if(ComboConnectToUser.Items.Count > 0)
                ComboConnectToUser.SelectedIndex = 0;
        }

        private void AddRooms()
        {
            ComboPutInConf.Items.Clear();

            ArrayList objListRooms = new ArrayList();
            m_objVaxTeleSIP.GetRoomAll(ref objListRooms);

            if(objListRooms.Count <= 0) return;

            for (int nCount = 0; nCount < objListRooms.Count; nCount++)
                ComboPutInConf.Items.Add(objListRooms[nCount]);

            if(ComboPutInConf.Items.Count > 0)
                ComboPutInConf.SelectedIndex = 0;
        }

        public void OnSetActive()
        {
            AddUsers();
            AddRooms();
            AddQueues();
            AddRingGroups();
            AddLines();

            ShowLineDetails();
        }

        private Boolean AddLineChecks()
        {
            if(ComboLine.Text.Length == 0)
            {
                MessageBox.Show("Please enter Line Name.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return false;
            }

            if(ListBoxEnableCodec.Items.Count == 0)
            {
                MessageBox.Show("Please select a codec.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return false;
            }

            return true;
        }

        private void ShowLineDetails()
        {
            String sLineName = ComboLine.Text;
            
            if (sLineName.Length == 0)
                return;
            
            string sDisplayName = "", sUserName = "", sAuthUser = "";
            string sAuthPwd = "", sDomainRealm = "", sProxySIP = "";
            string sCodecList = "", sToPeerName = "", sRoomName = "", sQueueName = "", sRingGroupName = "";

            int nToPeerType = -1;
            bool bRegister = false, bRejected = false;

            m_objVaxTeleSIP.GetLineDetails(sLineName, ref sDisplayName, ref sUserName, ref sAuthUser, ref sAuthPwd, ref sDomainRealm, ref sProxySIP, ref sCodecList, ref bRegister, ref nToPeerType, ref sToPeerName, ref bRejected, ref sRoomName, ref sQueueName, ref sRingGroupName);
            UpdateDlgContent(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);
        }

        private void UpdateDlgContent(string sLineName, string sDisplayName, string sUserName, string sAuthUser, string sAuthPwd, string sRealm, string sProxy, string sCodecList, bool bRegister, long lToPeerType, string sToPeerName, bool bRejected, string sRoomName, string sQueueName, string sRingGroupName)
        {
            if(sLineName.Length == 0)
                return;

            EditDisplayName.Text = sDisplayName;
            EditUserName.Text = sUserName;

            EditAuthUser.Text = sAuthUser;
            EditPassword.Text = sAuthPwd;
            EditDomainRealm.Text = sRealm;
            EditProxySIP.Text = sProxy;

            CheckBoxRegLine.Checked = bRegister;

            UpdateIncomingCallSection((int)lToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sRingGroupName);

            ListBoxEnableCodec.Items.Clear();
            ListBoxDisableCodec.Items.Clear();

            cCodec objCodec = new cCodec();

            for (int nCount = 0; nCount < cCodec.TOTAL_SIZE_CODEC; nCount++)
                ListBoxDisableCodec.Items.Add(objCodec.GetCodecName(Convert.ToString(nCount)));

            string sCodecName;

            for (int nCount = 0; nCount < sCodecList.Length; nCount++)
            {
                sCodecName = objCodec.GetCodecName(sCodecList[nCount].ToString());
                ListBoxEnableCodec.Items.Add(sCodecName);
                ListBoxDisableCodec.Items.Remove(sCodecName);
            }
        }

        private void UpdateIncomingCallSection(int nToPeerType, string sToPeerName, bool bRejected, string sRoomName, string sQueueName, string sRingGroupName)
        {
            if(bRejected)
            {
                RadioRejectCall.Checked = true;
            }
            else if(nToPeerType == cVaxServerCOM.VAX_PEER_TYPE_USER)
            {
                int nIndex = ComboConnectToUser.FindStringExact(sToPeerName);
                if(nIndex == -1) return;

                if(ComboConnectToUser.Items.Count > 0)
                    ComboConnectToUser.SelectedIndex = nIndex;

                RadioConnectToUser.Checked = true;
            }
            else if(sRoomName.Length != 0)
            {
                int nIndex = ComboPutInConf.FindStringExact(sRoomName);
                if(nIndex == -1) return;

                if(ComboPutInConf.Items.Count > 0)
                    ComboPutInConf.SelectedIndex = nIndex;

                RadioPutInConf.Checked = true;
            }

            else if(sQueueName.Length != 0)
            {
                int nIndex = comboQueueName.FindStringExact(sQueueName);
                if(nIndex == -1) return;

                if(comboQueueName.Items.Count > 0)
                    comboQueueName.SelectedIndex = nIndex;

                RbtnQueue.Checked = true;
            }

            else if(sRingGroupName.Length != 0)
            {
                int nIndex = comboRingGroupName.FindStringExact(sRingGroupName);
                if(nIndex == -1) return;

                if(comboRingGroupName.Items.Count > 0)
                    comboRingGroupName.SelectedIndex = nIndex;

                RbtnRingGroup.Checked = true;
                return;
            }
        }
    }
}