using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using ServerSIP;

namespace VaxTeleConfigSIP
{
    public partial class LoginForm : Form
    {
        class ComboBoxRouteItem
        {
            public string m_sToPeerName { get; set; }
            public int m_nToPeerType { get; set; }

            public override string ToString()
            {
                return m_sToPeerName;
            }
        };


        private cVaxServerSIP m_objVaxTeleSIP;
                
        ArrayList m_arrComboBoxRouteItem;

        public LoginForm(ref cVaxServerSIP objVaxServer)
        {
            m_arrComboBoxRouteItem = new ArrayList();

            InitializeComponent();

            m_objVaxTeleSIP = objVaxServer;
        }

        private void LoginForm_Load(object sender, EventArgs e)
        {
            LoadCodecs();
        }
       
        private void BtnAddLogin_Click(object sender, EventArgs e)
        {
            if(AddLoginChecks() == false)
                return;

            if(ComboLogin.FindStringExact(ComboLogin.Text) != -1)
            {
                if(MessageBox.Show("Login already exists, do you want to continue?", "VaxTeleSIP", MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation) == DialogResult.No)
                {
                    return;
                }
            }

            cCodec objCodec = new cCodec();
            string sCodec = "";

            for(int nCount = 0; nCount < ListBoxEnableCodec.Items.Count; nCount++)
                sCodec += objCodec.GetCodecNo(ListBoxEnableCodec.Items[nCount].ToString());

            int nSelectedIndex = ComboLoginRoute.SelectedIndex;

            int nToPeerType = -1;
            String sToPeerName = "";

            if(nSelectedIndex != -1)
            {
                ComboBoxRouteItem ComboLineItem = (ComboBoxRouteItem)m_arrComboBoxRouteItem[nSelectedIndex];

                nToPeerType = ComboLineItem.m_nToPeerType;
                sToPeerName = ComboLineItem.m_sToPeerName;
            }

            if(ComboLogin.Items.Contains(ComboLogin.Text))
                m_objVaxTeleSIP.RemoveUser(ComboLogin.Text);

            if(m_objVaxTeleSIP.AddUser(ComboLogin.Text, EditPassword.Text, sCodec, CheckBoxBlockAccount.Checked, EditCallPrefix.Text, EditDialPrefix.Text, nToPeerType, sToPeerName, checkBoxStealthListen.Checked) == false)
            {
                MessageBox.Show("Login could not be created or Please start the server first.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }

            if(!ComboLogin.Items.Contains(ComboLogin.Text))
                ComboLogin.Items.Add(ComboLogin.Text);

            MessageBox.Show("Login added/updated successfully.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
        }
                
        private void BtnDisableCodec_Click(object sender, EventArgs e)
        {
            if(ListBoxEnableCodec.SelectedItems.Count == 0) return;

            ListBoxDisableCodec.Items.Add(ListBoxEnableCodec.SelectedItem.ToString());
            ListBoxEnableCodec.Items.Remove(ListBoxEnableCodec.SelectedItem);
        }

        private void BtnEnableCodec_Click(object sender, EventArgs e)
        {
            if(ListBoxDisableCodec.SelectedItems.Count == 0) return;

            ListBoxEnableCodec.Items.Add(ListBoxDisableCodec.SelectedItem.ToString());
            ListBoxDisableCodec.Items.Remove(ListBoxDisableCodec.SelectedItem);
        }

        private void ClearDlgContent()
        {
            ComboLogin.Text = "";
            ComboLoginRoute.Text = "";

            EditPassword.Text = "";
            EditCallPrefix.Text = "";
            EditDialPrefix.Text = "";


            ListBoxEnableCodec.Items.Clear();
            ListBoxDisableCodec.Items.Clear();

            CheckBoxBlockAccount.Checked = false;
            checkBoxStealthListen.Checked = false;

            ListBoxEnableCodec.Items.Add(cCodec.G711U_TEXT);
            ListBoxEnableCodec.Items.Add(cCodec.G711A_TEXT);
            ListBoxEnableCodec.Items.Add(cCodec.ILBC_TEXT);
            ListBoxEnableCodec.Items.Add(cCodec.G610_TEXT);
            ListBoxEnableCodec.Items.Add(cCodec.G729_TEXT);
        }

        private void LoadCodecs()
        {
            cCodec objCodec = new cCodec();

            for (int nCount = 0; nCount < cCodec.TOTAL_SIZE_CODEC; nCount++)
                ListBoxEnableCodec.Items.Add(objCodec.GetCodecName(Convert.ToString(nCount)));
        }

        private void ComboLogin_SelectedIndexChanged(object sender, EventArgs e)
        {
            ShowUserDetails();
        }

        private void BtnClearLoginDlg_Click(object sender, EventArgs e)
        {
            ClearDlgContent();
        }

        private void BtnRemoveLogin_Click(object sender, EventArgs e)
        {
            if(ComboLogin.Text.Length == 0)
            {
                MessageBox.Show("Please enter a login name.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return;
            }

            int nIndex = ComboLogin.FindStringExact(ComboLogin.Text);
            if(nIndex == -1) return;

            m_objVaxTeleSIP.RemoveUser(ComboLogin.Text);
            ComboLogin.Items.RemoveAt(nIndex);

            ClearDlgContent();
            
            if (ComboLogin.Items.Count > 0)
                ComboLogin.SelectedIndex = 0;

            ShowUserDetails();

            MessageBox.Show("Login removed successfully!", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
        }

        private void AddUsers()
        {
            ComboLogin.Items.Clear();

            ArrayList objListUsers = new ArrayList();
            m_objVaxTeleSIP.GetUserAll(ref objListUsers);

            if(objListUsers.Count <= 0) return;

            for (int nIndex = 0; nIndex < objListUsers.Count; nIndex++)
                ComboLogin.Items.Add(objListUsers[nIndex]);

            if(ComboLogin.Items.Count > 0)
                ComboLogin.SelectedIndex = 0;
        }

        private void AddLines()
        {
            ArrayList objListLines = new ArrayList();
            m_objVaxTeleSIP.GetLineAll(ref objListLines);

            if(objListLines.Count <= 0) return;

            for (int nIndex = 0; nIndex < objListLines.Count; nIndex++)
            {
                string sRouteName = objListLines[nIndex].ToString();
                int nItemIndex = ComboLoginRoute.Items.Add(sRouteName);

                ComboBoxRouteItem comboRouteItem = new ComboBoxRouteItem();
                comboRouteItem.m_sToPeerName = objListLines[nIndex].ToString();
                comboRouteItem.m_nToPeerType = cVaxServerCOM.VAX_PEER_TYPE_LINE;

                m_arrComboBoxRouteItem.Add(comboRouteItem);
            }
                        
            if (ComboLoginRoute.Items.Count > 0)
                ComboLoginRoute.SelectedIndex = 0;
        }

        private void AddDirectProxies()
        {
            ArrayList objProxyList = new ArrayList();
            m_objVaxTeleSIP.GetDirectProxyAll(ref objProxyList);

            if(objProxyList.Count <= 0) return;

            for (int nIndex = 0; nIndex < objProxyList.Count; nIndex++)
            {
                string sRouteName = objProxyList[nIndex].ToString();
                int nItemIndex = ComboLoginRoute.Items.Add(sRouteName);

                ComboBoxRouteItem comboRouteItem = new ComboBoxRouteItem();
                comboRouteItem.m_sToPeerName = objProxyList[nIndex].ToString();
                comboRouteItem.m_nToPeerType = cVaxServerCOM.VAX_PEER_TYPE_DIRECT_PROXY;

                m_arrComboBoxRouteItem.Add(comboRouteItem);
            }

            if (ComboLoginRoute.Items.Count > 0)
                ComboLoginRoute.SelectedIndex = 0;
        }

        public void OnSetActive()
        {
            ComboLoginRoute.Items.Clear();

            AddLines();
            AddDirectProxies();
            AddUsers();

            ShowUserDetails();
        }

        private void ShowUserDetails()
        {
            String sLogin = ComboLogin.Text;
            
            if(sLogin.Length == 0)
                return;
            
            string sPassword = "", sUserPrefix = "";
            string sDialPrefix = "", sCodecList = "", sToPeerName = "";
            int nToPeerType = -1;
            bool bBlock = true;
            bool bStealthlisten = true;

            m_objVaxTeleSIP.GetUserDetails(sLogin, ref sPassword, ref sCodecList, ref bBlock, ref sUserPrefix, ref sDialPrefix, ref nToPeerType, ref sToPeerName, ref bStealthlisten);
            UpdateDlgContent(sLogin, sPassword, sCodecList, sDialPrefix, sUserPrefix, sToPeerName, bBlock, bStealthlisten);
        }

        private void UpdateDlgContent(string sLoginSIP, string sPassword, string sCodecList, string sDialPrefix, string sUserPrefix, string sToPeerName, bool bBlock, bool bStealthlisten)
        {
            if(sLoginSIP.Length == 0)
                return;

            EditPassword.Text = sPassword;
            EditDialPrefix.Text = sDialPrefix;
            EditCallPrefix.Text = sUserPrefix;

            ComboLoginRoute.SelectedIndex = ComboLoginRoute.FindStringExact(sToPeerName);

            ListBoxEnableCodec.Items.Clear();
            ListBoxDisableCodec.Items.Clear();

            cCodec objCodec = new cCodec();

            for (int nCount = 0; nCount < cCodec.TOTAL_SIZE_CODEC; nCount++)
                ListBoxDisableCodec.Items.Add(objCodec.GetCodecName(Convert.ToString(nCount)));

            string sCodecName;

            for (int nCount = 0; nCount < sCodecList.Length; nCount++)
            {
                sCodecName = objCodec.GetCodecName(sCodecList[nCount].ToString());
                ListBoxEnableCodec.Items.Add(sCodecName);
                ListBoxDisableCodec.Items.Remove(sCodecName);
            }

            CheckBoxBlockAccount.Checked = bBlock;
            checkBoxStealthListen.Checked = bStealthlisten;
        }

        private Boolean AddLoginChecks()
        {

            if(ComboLogin.Text.Length == 0)
            {
                MessageBox.Show("Please enter login.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return false;
            }

            string sDigit = "0123456789";

            for (int nCount = 0; nCount < ComboLogin.Text.Length; nCount++)
            {
                if(sDigit.IndexOf(ComboLogin.Text[nCount]) == -1)
                {
                    MessageBox.Show("Login should contain only numerals 0 through 9. For example: 12, 324323, 800122, 2109756 etc.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                    return false;
                }
            }

            if(EditPassword.Text.Length == 0)
            {
                MessageBox.Show("Please enter login password.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return false;
            }

            if(ComboLogin.Text.Length > 20 || EditPassword.Text.Length > 20)
            {
                MessageBox.Show("Login && password size should not be more than 20.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return false;
            }

            if(ComboLogin.Text.Substring(0, 2) == "00")
            {
                MessageBox.Show("Please do not enter 00 as login prefix. 00 prefix is use to prepare dial plan.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return false;
            }

            if(ListBoxEnableCodec.Items.Count == 0)
            {
                MessageBox.Show("Please select a codec.", "VaxTeleSIP", MessageBoxButtons.OK, MessageBoxIcon.Exclamation);
                return false;
            }

            return true;

        }


        
    }
}