﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using System.Text;

using VaxTeleConfigSIP;

namespace ServerSIP
{
    public class cVaxServerSIP : cVaxServerExCOM
    {
        public MainForm m_objMainFormDlg = null;

        cVaxSettingDefault m_objSettingDefault;
        
        const string HOLD_MUSIC_FILE = "Hold.wav";
        const string DIAL_TONE_MUSIC_FILE = "DialTone.wav";
        const string CALL_PARKING_MUSIC_FILE = "Hold.wav";
        
        public cVaxServerSIP()
        {
            m_objSettingDefault = new cVaxSettingDefault(this);
        }

        ~cVaxServerSIP()
        { 
        
        }

        //////////////////////////////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////////////////////////////

        public bool Initialize(string sDomainRealm, string sSIPListenIP, int nSIPListenPort)
        {
            cStoreCOMM objStoreCOMM = new cStoreCOMM();

            if (!objStoreCOMM.Initialize(sDomainRealm, sSIPListenIP, nSIPListenPort, sSIPListenIP, -1))
                return false;

            if (!base.Initialize(sDomainRealm, sSIPListenIP, nSIPListenPort, sSIPListenIP, -1))
                return false;

            base.SetListenPortRangeRTP(20000, 30000);
            return true;
        }

        public bool GetInitialize(ref  string sSIPListenIP, ref  int nSIPListenPort)
        {
            cStoreCOMM objStoreCOMM = new cStoreCOMM();

            string sDomainRealm = "", sRTPListenIP = "";
            int nRTPListenPort = -1;

            if(!objStoreCOMM.GetInitialize(ref sDomainRealm, ref sSIPListenIP, ref nSIPListenPort, ref sRTPListenIP, ref nRTPListenPort))
                return false;

            return true;
        }

        public new bool LoadMusicHold(string sFileName)
        {
            if(!base.LoadMusicHold(sFileName))
                return false;

            cStoreCOMM objStoreCOMM = new cStoreCOMM();
            objStoreCOMM.SetMusicHold(sFileName);
            
            return true;
        }

        public string GetMusicHold()
        {
            cStoreCOMM objStoreCOMM = new cStoreCOMM();
            string sFileName = "";

            if(!objStoreCOMM.GetMusicHold(ref sFileName))
            {
                sFileName = HOLD_MUSIC_FILE;
            }

            return sFileName;
        }

        public new bool LoadMusicDialTone(string sFileName)
        {
            if(!base.LoadMusicDialTone(sFileName))
                return false;

            cStoreCOMM objStoreCOMM = new cStoreCOMM();
            objStoreCOMM.SetMusicDialTone(sFileName);

            return true;
        }

        public string GetMusicDialTone()
        {
            cStoreCOMM objStoreCOMM = new cStoreCOMM();
            string sFileName = "";

            if(!objStoreCOMM.GetMusicDialTone(ref sFileName))
            {
                sFileName = DIAL_TONE_MUSIC_FILE;
            }

            return sFileName;
        }

        public new bool LoadMusicCallParking(string sFileName)
        {
            if(!base.LoadMusicCallParking(sFileName))
                return false;

           cStoreCOMM objStoreCOMM = new cStoreCOMM();
            objStoreCOMM.SetMusicCallParking(sFileName);

            return true;
        }

        public new string GetMusicCallParking()
        {
            cStoreCOMM objStoreCOMM = new cStoreCOMM();
            string sFileName = "";

            if(!objStoreCOMM.GetMusicCallParking(ref sFileName))
            {
                sFileName = CALL_PARKING_MUSIC_FILE;
            }

            return sFileName;
        }

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        public new bool AddUser(string sLogin, string sPassword, string sCodecList, bool bBlocked, string sUserPrefix, string sDialPrefix, int nToPeerType, string sToPeerName, bool bStealthlisten)
        {
            if(!base.IsInitialized())
                return false;

            if(sLogin.Length == 0)
                return false;

            RemoveUser(sLogin);

            cStoreUser objStoreUser = new cStoreUser();
            objStoreUser.AddUser(sLogin, sPassword, sCodecList, bBlocked, bStealthlisten);

            if(sUserPrefix.Length != 0 || sDialPrefix.Length != 0)
            {
                objStoreUser.AddUserRoute(sLogin, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
                base.AddUserRoute(sLogin, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
            }

            return base.AddUser(sLogin, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName, bStealthlisten);
        }

        public new void RemoveUser(string sLogin)
        {
            if(!base.IsInitialized())
                return;

            if(sLogin.Length == 0)
                return;

            cStoreUser objStoreUser = new cStoreUser();
            objStoreUser.RemoveUserRoute(sLogin);
            objStoreUser.RemoveUser(sLogin);

            base.RemoveUserRoute(sLogin);
            base.RemoveUser(sLogin);         
        }

        public void GetUserAll(ref ArrayList objList)
        {
            if(!base.IsInitialized())
                return;

            List<string> objListUserName = new List<string>();

            cStoreUser objStoreUser = new cStoreUser();
            objStoreUser.GetUserNameAll(ref objListUserName);

            objList.AddRange(objListUserName);
        }

        public bool GetUserDetails(string sUserName, ref string sPassword, ref string sCodecList, ref bool bBlocked, ref string sUserPrefix, ref string sDialPrefix, ref int nToPeerType, ref string sToPeerName, ref bool bStealthlisten)
        {
            if(!base.IsInitialized())
                return false;

            cStoreUser objStoreUser = new cStoreUser();
            objStoreUser.GetUser(sUserName, ref sPassword, ref sCodecList, ref bBlocked, ref bStealthlisten);
            objStoreUser.GetUserRoute(sUserName, ref sUserPrefix, ref sDialPrefix, ref nToPeerType, ref sToPeerName);

            return true;
        }

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        public new bool AddLine(string sLineName, string sDisplayName, string sUserName, string sAuthUser, string sAuthPwd, string sDomainRealm, string sProxySIP, string sCodecList, bool bRegister, int nToPeerType, string sToPeerName, bool bRejected, string sRoomName, string sQueueName, string sGroupName)
        {
            if(!base.IsInitialized())
                return false;

            this.RemoveLine(sLineName);

            cStoreLine objStoreLine = new cStoreLine();

            objStoreLine.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, "", sCodecList, bRegister);
            objStoreLine.AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sGroupName);

            base.AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sGroupName);
            return base.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sGroupName);
        }

        public new void RemoveLine(string sLineName)
        {
            if(!base.IsInitialized())
                return;

            cStoreLine objStoreLine = new cStoreLine();
            objStoreLine.RemoveLine(sLineName);
            objStoreLine.RemoveLineRoute(sLineName);

            base.RemoveLine(sLineName);
            base.RemoveLineRoute(sLineName);
        }

        public void GetLineAll(ref ArrayList objList)
        {
            if(!base.IsInitialized())
                return;

            List<string> objListLineName = new List<string>();

            cStoreLine objStoreLine = new cStoreLine();
            objStoreLine.GetLineNameAll(ref objListLineName);

            objList.AddRange(objListLineName);
        }

        public bool GetLineDetails(string sLineName, ref string sDisplayName, ref string sUserName, ref string sAuthUser, ref string sAuthPwd, ref string sDomainRealm, ref string sProxySIP, ref string sCodecList, ref bool bRegister, ref int nToPeerType, ref string sToPeerName, ref bool bRejected, ref string sRoomName, ref string sQueueName, ref string sGroupName)
        {
            if(!base.IsInitialized())
                return false;

            cStoreLine objStoreLine = new cStoreLine();

            string sOutBountProxySIP = "";
            objStoreLine.GetLine(sLineName, ref sDisplayName, ref sUserName, ref sAuthUser, ref sAuthPwd, ref sDomainRealm, ref sProxySIP, ref sOutBountProxySIP, ref sCodecList, ref bRegister);
            objStoreLine.GetLineRoute(sLineName, ref nToPeerType, ref sToPeerName, ref bRejected, ref sRoomName, ref sQueueName, ref sGroupName);

            return true;
        }

        /////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////

        public new bool AddDirectProxySIP(string sProxyName, string sAuthLogin, string sAuthPwd, string sDomainRealm, string sProxyIP, int nProxyPort, string sCodecList, int nToPeerType, string sToPeerName, bool bRejected, string sRoomName, string sQueueName, string sGroupName)
        {
            if(!base.IsInitialized())
                return false;

            this.RemoveDirectProxySIP(sProxyName);

            cStoreDirectProxy objStoreDirectProxy = new cStoreDirectProxy();

            objStoreDirectProxy.AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList);
            objStoreDirectProxy.AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sGroupName);


            base.AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sGroupName);
            return base.AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sGroupName);
        }

        public new void RemoveDirectProxySIP(string sProxyName)
        {
            if(!base.IsInitialized())
                return;

            cStoreDirectProxy objStoreDirectProxy = new cStoreDirectProxy();

            objStoreDirectProxy.RemoveDirectProxyRoute(sProxyName);
            objStoreDirectProxy.RemoveDirectProxySIP(sProxyName);

            base.RemoveDirectProxyRoute(sProxyName);
            base.RemoveDirectProxySIP(sProxyName);
        }

        public void GetDirectProxyAll(ref ArrayList objList)
        {
            if(!base.IsInitialized())
                return;

            List<string> objListProxiesName = new List<string>();

            cStoreDirectProxy objStoreDirectProxy = new cStoreDirectProxy();
            objStoreDirectProxy.GetDirectProxySIPAll(ref objListProxiesName);

            objList.AddRange(objListProxiesName);
        }

        public bool GetDirectProxyDetails(string sProxyName, ref string sAuthLogin, ref string sAuthPwd, ref string sDomainRealm, ref string sProxyIP, ref int nProxyPort, ref string sCodecList, ref int nToPeerType, ref string sToPeerName, ref bool bCallReject, ref string sRoomName, ref string sQueueName, ref string sGroupName)
        {
            if(!base.IsInitialized())
                return false;

            cStoreDirectProxy objStoreDirectProxy = new cStoreDirectProxy();
            objStoreDirectProxy.GetDirectProxySIP(sProxyName, ref sAuthLogin, ref sAuthPwd, ref sDomainRealm, ref sProxyIP, ref nProxyPort, ref sCodecList);
            objStoreDirectProxy.GetDirectProxyRoute(sProxyName, ref nToPeerType, ref sToPeerName, ref bCallReject, ref sRoomName, ref sQueueName, ref sGroupName);

            return true;
        }

        ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
        ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////

        public new bool AddRoom(string sRoomName, string sRoomNo)
        {
            if(!base.IsInitialized())
                return false;

            this.RemoveRoom(sRoomName);

            if (!base.AddRoom(sRoomName, sRoomNo))
                return false;

            cStoreRoom objStoreRoom = new cStoreRoom();
            objStoreRoom.AddRoom(sRoomName, sRoomNo);

            return true;
        }

        public new void RemoveRoom(string sRoomName)
        {
            if(!base.IsInitialized())
                return;

            cStoreRoom objStoreRoom = new cStoreRoom();
            objStoreRoom.RemoveRoom(sRoomName);

            base.RemoveRoom(sRoomName);
        }

        public bool GetRoomDetails(string sRoomName, ref string sRoomNo)
        {
            if(!base.IsInitialized())
                return false;

            cStoreRoom objStoreRoom = new cStoreRoom();
            objStoreRoom.GetRoom(sRoomName, ref sRoomNo);
            return true;
        }

        public bool GetRoomAll(ref ArrayList aRoomList)
        {
            if(!base.IsInitialized())
                return false;

            List<string> objListRoomNameList = new List<string>();
            cStoreRoom objStoreRoom = new cStoreRoom();
            
            objStoreRoom.GetRoomAll(ref objListRoomNameList);
            aRoomList.AddRange(objListRoomNameList);
            
            return true;
        }

        //////////////////////////////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////////////////////////////

        public new bool AddQueue(string sQueueName, string sQueueMusicFile, string sQueueDialToneFile)
        {
            if(!base.IsInitialized())
                return false;

            if(sQueueName.Length == 0)
                return false;

            if(!base.AddQueue(sQueueName, sQueueMusicFile, sQueueDialToneFile))
                return false;

            cStoreQueue objStoreQueue = new cStoreQueue();
            objStoreQueue.AddQueue(sQueueName);
            objStoreQueue.SetMusicFile(sQueueName, sQueueMusicFile);
            objStoreQueue.SetDialToneFile(sQueueName, sQueueDialToneFile);

            return true;
        }

        public new void RemoveQueue(string sQueueName)
        {
            if(!base.IsInitialized())
                return;

            if(sQueueName.Length == 0)
                return;

            cStoreQueue objStoreQueue = new cStoreQueue();
            objStoreQueue.RemoveQueue(sQueueName);
            
            base.RemoveQueue(sQueueName);
        }

        public bool GetQueueNameAll(ref List<string> objListQueueName)
        {
            if(!base.IsInitialized())
                return false;

            cStoreQueue objStoreQueue = new cStoreQueue();
            return objStoreQueue.GetQueueNameAll(ref objListQueueName);
        }

        public bool GetQueueDetails(string sQueueName, ref int nProcessMode, ref  int nProcessType, ref List<string> objListQueueAgent, ref string sQueueMusic, ref string sQueueDialTone)
        {
            if(!base.IsInitialized())
                return false;

            if(sQueueName.Length == 0)
                return false;

            objListQueueAgent.Clear();

            cStoreQueue objStoreQueue = new cStoreQueue();
            objStoreQueue.GetQueueProcessMode(sQueueName, ref nProcessMode, ref nProcessType);
            objStoreQueue.GetQueueAgentNameAll(sQueueName, ref objListQueueAgent);
            
            objStoreQueue.GetMusicFile(sQueueName, ref sQueueMusic);
            objStoreQueue.GetDialToneFile(sQueueName, ref sQueueDialTone);
            return true;
        }

        public new bool AddQueueAgent(string sQueueName, string sUserName)
        {
            if(!base.IsInitialized())
                return false;

            if(sQueueName.Length == 0 || sUserName.Length == 0)
                return false;

            if(!base.AddQueueAgent(sQueueName, sUserName))
                return false;

            cStoreQueue objStoreQueue = new cStoreQueue();
            objStoreQueue.AddQueueAgent(sQueueName, sUserName);

            return true;
        }

        public new void RemoveQueueAgent(string sQueueName, string sUserName)
        {
            if(!base.IsInitialized())
                return;

            if(sQueueName.Length == 0 || sUserName.Length == 0)
                return;

            cStoreQueue objStoreQueue = new cStoreQueue();
            objStoreQueue.RemoveQueueAgent(sQueueName, sUserName);

            base.RemoveQueueAgent(sQueueName, sUserName);
        }

        public new void SetQueueAgentPriority(string sQueueName, string sUserName, int nPriorityWeight)
        {
            if(!base.IsInitialized())
                return;

            if(sQueueName.Length == 0 || sUserName.Length == 0)
                return;
          
            cStoreQueue objStoreQueue = new cStoreQueue();
            objStoreQueue.SetQueueAgentPriority(sQueueName, sUserName, nPriorityWeight);
            
            base.SetQueueAgentPriority(sQueueName, sUserName, nPriorityWeight);
        }
        
        public new void SetQueueProcessMode(string sQueueName, int nProcessMode, int nProcessType)
        {
            if(!base.IsInitialized())
                return;

            if(sQueueName.Length == 0)
                return;

            cStoreQueue objStoreQueue = new cStoreQueue();
            objStoreQueue.SetQueueProcessMode(sQueueName, nProcessMode, nProcessType);

            base.SetQueueProcessMode(sQueueName, nProcessMode, nProcessType);
        }

        ///////////////////////////////////////////////////////////////////////////////////////
        ///////////////////////////// RingGroup ///////////////////////////////////////////////

        public new bool AddRingGroup(string sGroupName)
        {
            if(!base.IsInitialized())
                return false;

            if(sGroupName.Length == 0)
                return false;

            if(!base.AddRingGroup(sGroupName))
                return false;

            cStoreRingGroup objStoreRingGroup = new cStoreRingGroup();
            objStoreRingGroup.AddRingGroup(sGroupName);

            return true;
        }

        public new void RemoveRingGroup(string sGroupName)
        {
            if(!base.IsInitialized())
                return;

            if(sGroupName.Length == 0)
                return;

            cStoreRingGroup objStoreRingGroup = new cStoreRingGroup();
            objStoreRingGroup.RemoveRingGroup(sGroupName);

            base.RemoveRingGroup(sGroupName);
        }

        public bool GetRingGroupNameAll(ref List<string> objListGroupName)
        {
            if(!base.IsInitialized())
                return false;

            objListGroupName.Clear();

            cStoreRingGroup objStoreRingGroup = new cStoreRingGroup();
            return objStoreRingGroup.GetRingGroupList(ref objListGroupName);
        }

        public bool GetRingGroupDetails(string sGroupName, ref int nProcessMode, ref  int nProcessType, ref List<string> objListRingGroupAgentName)
        {
            if(!base.IsInitialized())
                return false;

            if(sGroupName.Length == 0)
                return false;
            
            cStoreRingGroup objStoreRingGroup = new cStoreRingGroup();
            objStoreRingGroup.GetRingGroupProcessMode(sGroupName, ref nProcessMode, ref nProcessType);
            
            objListRingGroupAgentName.Clear();
            objStoreRingGroup.GetRingGroupAgentList(sGroupName, ref objListRingGroupAgentName);
            return true;
        }

        public new bool AddRingGroupAgent(string sGroupName, string sUserName)
        {
            if(!base.IsInitialized())
                return false;

            if(sGroupName.Length == 0 || sUserName.Length == 0)
                return false;

           if(!base.AddRingGroupAgent(sGroupName, sUserName))
               return false;

            cStoreRingGroup objStoreRingGroup = new cStoreRingGroup();
            objStoreRingGroup.AddRingGroupAgent(sGroupName, sUserName);
            return true;
        }

        public new void RemoveRingGroupAgent(string sGroupName, string sUserName)
        {
            if(!base.IsInitialized())
                return;

            if(sGroupName.Length == 0 || sUserName.Length == 0)
                return;
 
            cStoreRingGroup objStoreRingGroup = new cStoreRingGroup();
            objStoreRingGroup.RemoveRingGroupAgent(sGroupName, sUserName);

            base.RemoveRingGroupAgent(sGroupName, sUserName);
        }

        public new void SetRingGroupProcessMode(string sGroupName, int nProcessMode, int nProcessType)
        {
            if(!base.IsInitialized())
                return;

            if(sGroupName.Length == 0)
                return;
            
            cStoreRingGroup objStoreRingGroup = new cStoreRingGroup();
            objStoreRingGroup.SetRingGroupProcessMode(sGroupName, nProcessMode, nProcessType);
            
            base.SetRingGroupProcessMode(sGroupName, nProcessMode, nProcessType);
        }

        public new bool SetRingGroupAgentPriority(string sGroupName, string sUserName, int nPriority)
        {
            if(!base.IsInitialized())
                return false;

            if(sGroupName.Length == 0 || sUserName.Length == 0)
                return false;

            if(!base.SetRingGroupAgentPriority(sGroupName, sUserName, nPriority))
               return false;

           cStoreRingGroup objStoreRingGroup = new cStoreRingGroup();
           objStoreRingGroup.SetRingGroupAgentPriority(sGroupName, sUserName, nPriority);
           return true;
        }

        ////////////////////////////////////////////////////////////////////////////////////////////
        ////////////////////////////////////////////////////////////////////////////////////////////

        public new bool AddCallPickUpGroup(string sGroupName)
        {
            if(!base.IsInitialized())
                return false;

            if(sGroupName.Length == 0)
                return false;

            if(!base.AddCallPickUpGroup(sGroupName))
                return false;

            cStoreCallPickUp objStoreCallPickUp = new cStoreCallPickUp();
            objStoreCallPickUp.AddCallPickUpGroup(sGroupName);
            return true;
        }

        public new void RemoveCallPickUpGroup(string sGroupName)
        {
            if(!base.IsInitialized())
                return;

            if(sGroupName.Length == 0)
                return;

            base.RemoveCallPickUpGroup(sGroupName);

            cStoreCallPickUp objStoreCallPickUp = new cStoreCallPickUp();
            objStoreCallPickUp.RemoveCallPickUpGroup(sGroupName);
        }

        public bool GetPickUpGroupNameAll(ref List<string> objListPickUpName)
        {
            if(!base.IsInitialized())
                return false;

            objListPickUpName.Clear();

            cStoreCallPickUp objStoreCallPickUp = new cStoreCallPickUp();
            return objStoreCallPickUp.GetCallPickUpGroupNameAll(ref objListPickUpName);
        }

        public new bool AddCallPickUpGroupMember(string sGroupName, string sMemberName)
        {
            if(!base.IsInitialized())
                return false;

            if(sGroupName.Length == 0 || sMemberName.Length == 0)
                return false;

            if(!base.AddCallPickUpGroupMember(sGroupName, sMemberName))
                return false;

            cStoreCallPickUp objStoreCallPickUp = new cStoreCallPickUp();
            objStoreCallPickUp.AddCallPickUpGroupMember(sGroupName, sMemberName);
            
            return true;
        }

        public void RemoveCallPickUpMember(string sGroupName, string sMemberName)
        {
            if(!base.IsInitialized())
                return;

            if(sGroupName.Length == 0 || sMemberName.Length == 0)
                return;

            cStoreCallPickUp objStoreCallPickUp = new cStoreCallPickUp();
            objStoreCallPickUp.RemoveCallPickUpGroupMember(sGroupName, sMemberName);

            base.RemoveCallPickUpGroupMember(sGroupName, sMemberName);
        }

        public bool GetPickUpMemberNameAll(string sPickUpGroupName, ref List<string> objListMemberName)
        {
            objListMemberName.Clear();

            if(!base.IsInitialized())
                return false;

            if(sPickUpGroupName.Length == 0)
                return false;

            cStoreCallPickUp objStoreCallPickUp = new cStoreCallPickUp();
            return objStoreCallPickUp.GetPickUpMemberNameAll(sPickUpGroupName, ref objListMemberName);
        }

        //////////////////////////////////////////////////////////////////////////////////////////////////////////
        //////////////////////////////////////////////////////////////////////////////////////////////////////////

        private void LoadUser()
        {
            if(!base.IsInitialized())
                return;

            List<string> objListUsers = new List<string>();

            cStoreUser objStoreUsre = new cStoreUser();
            objStoreUsre.GetUserNameAll(ref objListUsers);

            if(objListUsers.Count == 0)
                return;

            string sPassword = "", sCodecList = "";
            string sUserPrefix = "", sDialPrefix = "", sToPeerName = "";

            bool bBlocked = false, bStealthListen = false;
            int nToPeerType = -1;

            foreach (string sUserName in objListUsers)
            {
               objStoreUsre.GetUser(sUserName, ref sPassword, ref sCodecList, ref bBlocked, ref bStealthListen);
               objStoreUsre.GetUserRoute(sUserName, ref sUserPrefix, ref sDialPrefix, ref nToPeerType, ref sToPeerName);
   
               if(sUserPrefix.Length != 0 || sDialPrefix.Length != 0)
               {
                 base.AddUserRoute(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
               }

               base.AddUser(sUserName, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName, bStealthListen);
            }
        }

        private void LoadLine()
        {
            if(!base.IsInitialized())
                return;

            List<string> objListLines = new List<string>();

            cStoreLine objStoreLine = new cStoreLine();
            objStoreLine.GetLineNameAll(ref objListLines);
            
            if (objListLines.Count == 0)
                return;

            string sDisplayName = "", sUserName = "", sAuthUser = "", sAuthPwd = "", sDomainRealm = "", sProxySIP = "", sCodecList = "", sOutboundProxySIP = "";
            string sToPeerName = "", sRoomName = "", sQueueName = "", sGroupName = "";

            bool bRejected = false, bRegister = false;
            int nToPeerType = -1;
                        
            foreach (string sLineName in objListLines)
            {
                objStoreLine.GetLine(sLineName, ref sDisplayName, ref sUserName, ref sAuthUser, ref sAuthPwd, ref sDomainRealm, ref sProxySIP, ref sOutboundProxySIP, ref sCodecList, ref bRegister);
                objStoreLine.GetLineRoute(sLineName, ref nToPeerType, ref sToPeerName, ref bRejected, ref sRoomName, ref sQueueName, ref sGroupName);

                base.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sGroupName);
                base.AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName, sQueueName, sGroupName);
            }
        }

        private void LoadDirectProxy()
        {
            if(!base.IsInitialized())
                return;

            List<string> objListProxy = new List<string>();

            cStoreDirectProxy objStoreProxy = new cStoreDirectProxy();
            objStoreProxy.GetDirectProxySIPAll(ref objListProxy);

            if(objListProxy.Count == 0)
                return;

            string sAuthLogin = "", sAuthPwd = "", sDomainRealm = "", sProxyIP = "", sCodecList = "", sToPeerName = "", sRoomName = "";
            string sQueueName = "", sGroupName = "";
            int nProxyPort = -1, nToPeerType = -1;

            bool bCallRejected = false;
            
            foreach (string sProxy in objListProxy)
            {
                objStoreProxy.GetDirectProxySIP(sProxy, ref sAuthLogin, ref sAuthPwd, ref sDomainRealm, ref sProxyIP, ref nProxyPort, ref sCodecList);
                objStoreProxy.GetDirectProxyRoute(sProxy, ref nToPeerType, ref sToPeerName, ref bCallRejected, ref sRoomName, ref sQueueName, ref sGroupName);

                base.AddDirectProxySIP(sProxy, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList, nToPeerType, sToPeerName, bCallRejected, sRoomName, sQueueName, sGroupName);
                base.AddDirectProxyRoute(sProxy, nToPeerType, sToPeerName, bCallRejected, sRoomName, sQueueName, sGroupName);
            }
        }
        
        private void LoadRoom()
        {
            if(!base.IsInitialized())
                return;

            List<string> objListRoom = new List<string>();
            cStoreRoom objStoreRoom = new cStoreRoom();
            string sRoomNo = "";

            objStoreRoom.GetRoomAll(ref objListRoom);
            if(objListRoom.Count == 0) return;

            foreach (string sRoomName in objListRoom)
            {
               objStoreRoom.GetRoom(sRoomName, ref sRoomNo);
               base.AddRoom(sRoomName, sRoomNo);
            }
        }

        private void LoadQueue()
        {
            if(!base.IsInitialized())
                return;

            List<string> objListQueue = new List<string>();

            cStoreQueue objStoreQueue = new cStoreQueue();
            objStoreQueue.GetQueueNameAll(ref objListQueue);

            if(objListQueue.Count == 0)
                return;

            List<string> objListQueueAgent = new List<string>();
            string sQueueMusicFile = "", sQueueDialToneMusic = "";
            int nProcessMode = -1, nProcessType = -1;

            foreach (string sQueueName in objListQueue)
            {
                objStoreQueue.GetMusicFile(sQueueName, ref sQueueMusicFile);
                objStoreQueue.GetDialToneFile(sQueueName, ref sQueueDialToneMusic);
                objStoreQueue.GetQueueAgentNameAll(sQueueName, ref objListQueueAgent);
                objStoreQueue.GetQueueProcessMode(sQueueName, ref nProcessMode, ref nProcessType);

                base.AddQueue(sQueueName, sQueueMusicFile, sQueueDialToneMusic);
                base.SetQueueProcessMode(sQueueName, nProcessMode, nProcessType);

                AddQueueAgents(sQueueName, objListQueueAgent);
                objListQueueAgent.Clear();
            }
        }

        private void AddQueueAgents(string sQueueName, List<string> objListQueueAgent)
        {
            cStoreQueue objStoreQueue = new cStoreQueue();
            int nPriority = -1;

            foreach (string sQueueAgentName in objListQueueAgent)
            {
                objStoreQueue.GetQueueAgentPriority(sQueueName, sQueueAgentName, ref nPriority);
                base.AddQueueAgent(sQueueName, sQueueAgentName);
                base.SetQueueAgentPriority(sQueueName, sQueueAgentName, nPriority);
            }
        }

        private void LoadRingGroup()
        {
            if(!base.IsInitialized())
                return;

            List<string> objListRingGroup = new List<string>();

            cStoreRingGroup objStoreRingGroup = new cStoreRingGroup();
            objStoreRingGroup.GetRingGroupList(ref objListRingGroup);

            if(objListRingGroup.Count == 0)
                return;

            List<string> objListRingGroupAgent = new List<string>();
            int nProcessMode = -1, nProcessType = -1;

            foreach (string sGroupName in objListRingGroup)
            {
                objStoreRingGroup.GetRingGroupAgentList(sGroupName, ref objListRingGroupAgent);
                objStoreRingGroup.GetRingGroupProcessMode(sGroupName, ref nProcessMode, ref nProcessType);

                base.AddRingGroup(sGroupName);
                base.SetRingGroupProcessMode(sGroupName, nProcessMode, nProcessType);

                AddRingGroupAgents(sGroupName, objListRingGroupAgent);
                objListRingGroupAgent.Clear();
            }
        }

        private void AddRingGroupAgents(string sGroupName, List<string> objListRingGroupAgent)
        {
            cStoreRingGroup objStoreRingGroup = new cStoreRingGroup();
            int nPriority = -1;

            foreach (string sRingGroupAgentName in objListRingGroupAgent)
            {
                objStoreRingGroup.GetRingGroupAgentPriority(sGroupName, sRingGroupAgentName, ref nPriority);
                base.AddRingGroupAgent(sGroupName, sRingGroupAgentName);
                base.SetRingGroupAgentPriority(sGroupName, sRingGroupAgentName, nPriority);
            }
        }

        private void LoadCallPickUpGroup()
        {
            if(!base.IsInitialized())
                return;

            List<string> objListCallPickUp = new List<string>();

            cStoreCallPickUp objStoreCallPickUp = new cStoreCallPickUp();
            objStoreCallPickUp.GetCallPickUpGroupNameAll(ref objListCallPickUp);

            if(objListCallPickUp.Count == 0)
                return;

            List<string> objListCallPickUpAgent = new List<string>();
            foreach (string sPickupGroupName in objListCallPickUp)
            {
               objStoreCallPickUp.GetPickUpMemberNameAll(sPickupGroupName, ref objListCallPickUpAgent);

               base.AddCallPickUpGroup(sPickupGroupName);
               AddPickupGroupAgents(sPickupGroupName, objListCallPickUpAgent);
               objListCallPickUpAgent.Clear();
            }
        }

        private void AddPickupGroupAgents(string sPickupGroupName, List<string> objListCallPickUpAgent)
        {
            foreach (string sPickupAgent in objListCallPickUpAgent)
            {
               base.AddCallPickUpGroupMember(sPickupGroupName, sPickupAgent);
            }
        }
                
        /////////////////////////////////////////////////////////////////////////////////
        /////////////////////////////////////////////////////////////////////////////////
        
        public override void OnInitialize()
        {
            if (!m_objSettingDefault.LoadUserDefault())
            {
                LoadUser();
            }

            if (!m_objSettingDefault.LoadLineDefault())
            {
                LoadLine();
            }

            if (!m_objSettingDefault.LoadRoomDefault())
            {
                LoadRoom();
            }
                        
            LoadDirectProxy();

            if (!m_objSettingDefault.LoadQueueDefault())
            {
                LoadQueue();
            }

            if (!m_objSettingDefault.LoadRingGroupDefault())
            {
                LoadRingGroup();
            }

            if (!m_objSettingDefault.LoadCallPickUpGroupDefault())
            {
                LoadCallPickUpGroup();
            }
        }

        public override void OnStatusLog(string sMsg)
        {
            m_objMainFormDlg.PostStatusLog(sMsg);
        }
        public override void OnErrorLog(string sMsg)
        {
            m_objMainFormDlg.PostErrorLog(sMsg);
        }
    }
}
